# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: morai_actor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import morai_type_pb2 as morai__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11morai_actor.proto\x12\rmorai_sim_api\x1a\x1bgoogle/protobuf/empty.proto\x1a\x10morai_type.proto\"B\n\x10SpawnActorParams\x12.\n\x06params\x18\x01 \x03(\x0b\x32\x1e.morai_sim_api.SpawnActorParam\"\x9e\x02\n\x0fSpawnActorParam\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12+\n\ttransform\x18\x02 \x01(\x0b\x32\x18.morai_sim_api.Transform\x12\x33\n\x07vehicle\x18\x03 \x01(\x0b\x32 .morai_sim_api.VehicleSpawnParamH\x00\x12\x39\n\npedestrian\x18\x04 \x01(\x0b\x32#.morai_sim_api.PedestrianSpawnParamH\x00\x12\x35\n\x08obstacle\x18\x05 \x01(\x0b\x32!.morai_sim_api.ObstacleSpawnParamH\x00\x42\t\n\x07\x44\x65tails\"K\n\tActorInfo\x12\x10\n\x08\x61\x63tor_id\x18\x01 \x01(\t\x12,\n\nactor_type\x18\x02 \x01(\x0e\x32\x18.morai_sim_api.ActorType\"6\n\nActorInfos\x12(\n\x06values\x18\x01 \x03(\x0b\x32\x18.morai_sim_api.ActorInfo\"#\n\rActorTypeList\x12\x12\n\nactor_type\x18\x01 \x03(\t\"\x91\x01\n\x0eVehicleCtrlCmd\x12\x10\n\x08\x61\x63tor_id\x18\x01 \x01(\t\x12\x15\n\rlong_cmd_type\x18\x02 \x01(\x05\x12\x10\n\x08throttle\x18\x03 \x01(\x01\x12\r\n\x05\x62rake\x18\x04 \x01(\x01\x12\r\n\x05steer\x18\x05 \x01(\x01\x12\x10\n\x08velocity\x18\x06 \x01(\x01\x12\x14\n\x0c\x61\x63\x63\x65leration\x18\x07 \x01(\x01\"[\n\rWalkerCtrlCmd\x12\x10\n\x08\x61\x63tor_id\x18\x01 \x01(\t\x12)\n\tdirection\x18\x02 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12\r\n\x05speed\x18\x03 \x01(\x02\"8\n\x0b\x41\x63torStates\x12)\n\x06states\x18\x01 \x03(\x0b\x32\x19.morai_sim_api.ActorState\"\xd7\x02\n\nActorState\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12\x30\n\x0c\x62ounding_box\x18\x02 \x01(\x0b\x32\x1a.morai_sim_api.BoundingBox\x12+\n\ttransform\x18\x03 \x01(\x0b\x32\x18.morai_sim_api.Transform\x12(\n\x08velocity\x18\x04 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12\x30\n\x10\x61ngular_velocity\x18\x05 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12,\n\x0c\x61\x63\x63\x65leration\x18\x06 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12\x32\n\rvehicle_state\x18\x07 \x01(\x0b\x32\x1b.morai_sim_api.VehicleState\"\xb8\x01\n\x0cVehicleState\x12\x10\n\x08throttle\x18\x01 \x01(\x02\x12\r\n\x05steer\x18\x02 \x01(\x02\x12\r\n\x05\x62rake\x18\x03 \x01(\x02\x12\x19\n\x11\x66ront_wheel_angle\x18\x04 \x01(\x02\x12*\n\tgear_mode\x18\x05 \x01(\x0e\x32\x17.morai_sim_api.GearMode\x12\x31\n\taux_state\x18\x06 \x01(\x0b\x32\x1e.morai_sim_api.VehicleAuxState\"\xd3\x01\n\x0fVehicleAuxState\x12\x32\n\x11\x63urrent_link_info\x18\x01 \x01(\x0b\x32\x17.morai_sim_api.LinkInfo\x12\x1a\n\x12remaining_distance\x18\x02 \x01(\x02\x12\x17\n\x0fis_pass_des_pos\x18\x03 \x01(\x08\x12\r\n\x05tl_id\x18\x04 \x01(\t\x12\x32\n\x08tl_color\x18\x05 \x01(\x0e\x32 .morai_sim_api.TrafficLightColor\x12\x14\n\x0cis_collision\x18\x06 \x01(\x08\"c\n\x11VehicleSpawnParam\x12\x10\n\x08velocity\x18\x01 \x01(\x01\x12\x1a\n\x12vehicle_model_name\x18\x02 \x01(\t\x12\r\n\x05pause\x18\x03 \x01(\x08\x12\x11\n\tmulti_ego\x18\x04 \x01(\x08\"\x7f\n\x14PedestrianSpawnParam\x12\x10\n\x08velocity\x18\x01 \x01(\x02\x12\x13\n\x0b\x61\x63tive_dist\x18\x02 \x01(\x02\x12\x11\n\tmove_dist\x18\x03 \x01(\x02\x12\x17\n\x0fpedestrian_name\x18\x04 \x01(\t\x12\x14\n\x0cstart_action\x18\x05 \x01(\x08\"R\n\x12ObstacleSpawnParam\x12%\n\x05scale\x18\x01 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12\x15\n\robstacle_name\x18\x02 \x01(\t\"I\n\rActorResponse\x12\x0e\n\x06result\x18\x01 \x01(\x08\x12\x12\n\nactor_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\">\n\x0e\x41\x63torResponses\x12,\n\x06values\x18\x01 \x03(\x0b\x32\x1c.morai_sim_api.ActorResponse\"\xfa\x03\n\rActorProperty\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12.\n\x04type\x18\x02 \x01(\x0e\x32 .morai_sim_api.ActorPropertyType\x12-\n\ttransform\x18\x03 \x01(\x0b\x32\x18.morai_sim_api.TransformH\x00\x12/\n\x07network\x18\x04 \x01(\x0b\x32\x1c.morai_sim_api.NetworkConfigH\x00\x12\x11\n\x07physics\x18\x05 \x01(\x08H\x00\x12\x0c\n\x02\x61i\x18\x06 \x01(\x08H\x00\x12\x43\n\x15vehicle_event_control\x18\x07 \x01(\x0b\x32\".morai_sim_api.VehicleEventControlH\x00\x12\x38\n\x0fvehicle_limiter\x18\x08 \x01(\x0b\x32\x1d.morai_sim_api.VehicleLimiterH\x00\x12:\n\x10vehicle_dynamics\x18\t \x01(\x0b\x32\x1e.morai_sim_api.VehicleDynamicsH\x00\x12\x43\n\x15vehicle_control_state\x18\n \x01(\x0b\x32\".morai_sim_api.VehicleControlStateH\x00\x42\n\n\x08Property\"\x8d\x02\n\rNetworkConfig\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x31\n\tcomm_type\x18\x03 \x01(\x0e\x32\x1e.morai_sim_api.NetworkCommType\x12\x12\n\nframe_rate\x18\x04 \x01(\x05\x12@\n\x11protocol_settings\x18\x05 \x01(\x0b\x32%.morai_sim_api.NetworkProtocolSetting\x12\x34\n\x0bip_settings\x18\x06 \x03(\x0b\x32\x1f.morai_sim_api.NetworkIpSetting\"u\n\x10NetworkIpSetting\x12\x36\n\x0c\x63onnect_type\x18\x01 \x01(\x0e\x32 .morai_sim_api.NetworkConnetType\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.morai_sim_api.NetworkItem\"~\n\x16NetworkProtocolSetting\x12\x31\n\tcomm_type\x18\x01 \x01(\x0e\x32\x1e.morai_sim_api.NetworkCommType\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".morai_sim_api.NetworkProtocolItem\"n\n\x13NetworkProtocolItem\x12,\n\x08protocol\x18\x01 \x01(\x0e\x32\x1a.morai_sim_api.PUBSUB_TYPE\x12)\n\x05items\x18\x02 \x03(\x0b\x32\x1a.morai_sim_api.NetworkItem\"J\n\x0bNetworkItem\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.morai_sim_api.NetworkItemType\x12\r\n\x05value\x18\x02 \x01(\t\"\xf4\x01\n\x0cTrafficLight\x1a<\n\nTLSchedule\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\x12\x1c\n\x14str_light_color_list\x18\x02 \x03(\t\x1a\x81\x01\n\nPSSchedule\x12\x14\n\x0ctl_state_idx\x18\x01 \x01(\x05\x12\x15\n\rsynced_tl_idx\x18\x02 \x01(\x05\x12\x12\n\nbefore_sec\x18\x03 \x01(\x05\x12\x17\n\x0fgreen_light_sec\x18\x04 \x01(\x05\x12\x19\n\x11\x66licker_light_sec\x18\x05 \x01(\x05\x1a\"\n\x0eYellowSchedule\x12\x10\n\x08\x64uration\x18\x01 \x01(\x05\"\\\n\x06TLInfo\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05tl_id\x18\x02 \x01(\t\x12\x32\n\x08tl_color\x18\x03 \x01(\x0e\x32 .morai_sim_api.TrafficLightColor\"5\n\nTLInfoList\x12\'\n\x08res_list\x18\x01 \x03(\x0b\x32\x15.morai_sim_api.TLInfo\"e\n\x0cTLStateParam\x12\r\n\x05tl_id\x18\x01 \x01(\t\x12\x32\n\x08tl_color\x18\x02 \x01(\x0e\x32 .morai_sim_api.TrafficLightColor\x12\x12\n\nis_impulse\x18\x03 \x01(\x08\"A\n\x10TLStateParamList\x12-\n\x08req_list\x18\x01 \x03(\x0b\x32\x1b.morai_sim_api.TLStateParam\"8\n\x10IntscnStateParam\x12\x11\n\tintscn_id\x18\x01 \x01(\t\x12\x11\n\tstate_idx\x18\x02 \x01(\x05\"I\n\x14IntscnStateParamList\x12\x31\n\x08req_list\x18\x01 \x03(\x0b\x32\x1f.morai_sim_api.IntscnStateParam\"\xec\x01\n\x18IntersectionScheduleData\x12\x11\n\tintscn_id\x18\x01 \x01(\t\x12;\n\x0btl_schedule\x18\x02 \x03(\x0b\x32&.morai_sim_api.TrafficLight.TLSchedule\x12\x43\n\x0fyellow_schedule\x18\x03 \x03(\x0b\x32*.morai_sim_api.TrafficLight.YellowSchedule\x12;\n\x0bps_schedule\x18\x04 \x03(\x0b\x32&.morai_sim_api.TrafficLight.PSSchedule\"T\n\x17IntscnScheduleParamList\x12\x39\n\x08req_list\x18\x01 \x03(\x0b\x32\'.morai_sim_api.IntersectionScheduleData\"\xae\x01\n\x0cVehicleRoute\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12\x30\n\x0cvehicle_type\x18\x02 \x01(\x0e\x32\x1a.morai_sim_api.VehicleType\x12\x16\n\x0e\x64\x65\x63ision_range\x18\x03 \x01(\x02\x12&\n\x05links\x18\x04 \x03(\x0b\x32\x17.morai_sim_api.LinkInfo\"\xb6\x01\n\x12VehicleDestination\x12,\n\nactor_info\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.ActorInfo\x12\x30\n\x0cvehicle_type\x18\x02 \x01(\x0e\x32\x1a.morai_sim_api.VehicleType\x12\x16\n\x0e\x64\x65\x63ision_range\x18\x03 \x01(\x02\x12(\n\x08position\x18\x04 \x01(\x0b\x32\x16.morai_sim_api.Vector3\"\x91\x01\n\nEgoCtrlCmd\x12+\n\ttransform\x18\x01 \x01(\x0b\x32\x18.morai_sim_api.Transform\x12\x10\n\x08velocity\x18\x02 \x01(\x02\x12\r\n\x05pause\x18\x03 \x01(\x08\x12\x35\n\x0f\x63ruise_settings\x18\x04 \x01(\x0b\x32\x1c.morai_sim_api.EgoCruiseCtrl\"\x88\x01\n\rEgoCruiseCtrl\x12\x11\n\tcruise_on\x18\x01 \x01(\x08\x12/\n\x0b\x63ruise_type\x18\x02 \x01(\x0e\x32\x1a.morai_sim_api.CRUISE_TYPE\x12\x18\n\x10link_speed_ratio\x18\x03 \x01(\x05\x12\x19\n\x11\x63onstant_velocity\x18\x04 \x01(\x02\"\xa1\x01\n\x13VehicleEventControl\x12\x0e\n\x06option\x18\x01 \x01(\x05\x12\x11\n\tctrl_mode\x18\x02 \x01(\x05\x12%\n\x04gear\x18\x03 \x01(\x0e\x32\x17.morai_sim_api.GearMode\x12\x13\n\x0bturn_signal\x18\x04 \x01(\x05\x12\x18\n\x10\x65mergency_signal\x18\x05 \x01(\x05\x12\x11\n\tset_pause\x18\x06 \x01(\x08\"g\n\x0b\x44isturbance\";\n\x08Location\x12\t\n\x05\x41\x43\x43\x45L\x10\x00\x12\t\n\x05\x42RAKE\x10\x01\x12\t\n\x05STEER\x10\x02\x12\x0e\n\nHAND_BRAKE\x10\x03\"\x1b\n\x04Type\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05PULSE\x10\x01\"\xb7\x01\n\x12\x44isturbanceVehicle\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x36\n\tsituation\x18\x02 \x01(\x0e\x32#.morai_sim_api.Disturbance.Location\x12\x31\n\x08\x62\x65havior\x18\x03 \x01(\x0e\x32\x1f.morai_sim_api.Disturbance.Type\x12\x10\n\x08\x64uration\x18\x04 \x01(\x02\x12\x11\n\tmagnitude\x18\x05 \x01(\x02\"M\n\x16\x44isturbanceVehicleList\x12\x33\n\x08req_list\x18\x01 \x03(\x0b\x32!.morai_sim_api.DisturbanceVehicle\"X\n\x0bScenarioETC\"I\n\x0bSUBCATEGORY\x12\n\n\x06_BEGIN\x10\x00\x12\x0f\n\x0bSPAWN_POINT\x10\x01\x12\x13\n\x0fPED_SPAWN_POINT\x10\x02\x12\x08\n\x04_END\x10\x03\"\xda\x01\n\x0cVehicleClass\"F\n\x11VehicleLengthType\x12\x08\n\x04MINI\x10\x00\x12\x0b\n\x07\x43OMPACT\x10\x01\x12\x0f\n\x0bMIDDLE_SIZE\x10\x02\x12\t\n\x05LARGE\x10\x03\"\x81\x01\n\x0bSUBCATEGORY\x12\n\n\x06_BEGIN\x10\x00\x12\t\n\x05SEDAN\x10\x01\x12\x07\n\x03SUV\x10\x02\x12\x07\n\x03\x42US\x10\x03\x12\t\n\x05TRUCK\x10\x04\x12\t\n\x05WAGON\x10\x05\x12\x08\n\x04MISC\x10\x06\x12\x07\n\x03MPV\x10\x07\x12\n\n\x06\x43USTOM\x10\x08\x12\n\n\x06RANDOM\x10\t\x12\x08\n\x04_END\x10\n\"M\n\x08\x42iasMode\"A\n\x0bLatBiasMode\x12\n\n\x06_BEGIN\x10\x00\x12\x07\n\x03\x46IX\x10\x01\x12\x13\n\x0fRANDOM_GAUSSIAN\x10\x02\x12\x08\n\x04_END\x10\x03\"\x8d\x01\n\x10\x43reateSpawnPoint\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12(\n\x08position\x18\x02 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12<\n\x0csub_category\x18\x03 \x01(\x0e\x32&.morai_sim_api.ScenarioETC.SUBCATEGORY\"I\n\x14\x43reateSpawnPointList\x12\x31\n\x08req_list\x18\x01 \x03(\x0b\x32\x1f.morai_sim_api.CreateSpawnPoint\"8\n\x10\x45nableSpawnPoint\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12\x11\n\tis_active\x18\x02 \x01(\x08\"I\n\x14\x45nableSpawnPointList\x12\x31\n\x08req_list\x18\x01 \x03(\x0b\x32\x1f.morai_sim_api.EnableSpawnPoint\"\xb8\x07\n\x0eSpawnPointInfo\x12O\n\x18list_vehicle_length_type\x18\x01 \x03(\x0e\x32-.morai_sim_api.VehicleClass.VehicleLengthType\x12\x15\n\ris_close_loop\x18\x02 \x01(\x08\x12\x16\n\x0eis_lane_change\x18\x03 \x01(\x08\x12>\n\x0eparameter_type\x18\x04 \x01(\x0e\x32&.morai_sim_api.VehicleDrivingParamType\x12\x1d\n\x15maximum_spawn_vehicle\x18\x05 \x01(\x05\x12\x18\n\x10min_spawn_period\x18\x06 \x01(\x02\x12\x18\n\x10max_spawn_period\x18\x07 \x01(\x02\x12?\n\x13spawn_velocity_type\x18\x08 \x01(\x0e\x32\".morai_sim_api.VehicleVelocityType\x12!\n\x19min_spawn_velocity_custom\x18\t \x01(\x02\x12!\n\x19max_spawn_velocity_custom\x18\n \x01(\x02\x12\x1f\n\x17min_spawn_velocity_link\x18\x0b \x01(\x02\x12\x1f\n\x17max_spawn_velocity_link\x18\x0c \x01(\x02\x12\x41\n\x15\x64\x65sired_velocity_type\x18\r \x01(\x0e\x32\".morai_sim_api.VehicleVelocityType\x12#\n\x1bmin_desired_velocity_custom\x18\x0e \x01(\x02\x12#\n\x1bmax_desired_velocity_custom\x18\x0f \x01(\x02\x12!\n\x19min_desired_velocity_link\x18\x10 \x01(\x02\x12!\n\x19max_desired_velocity_link\x18\x11 \x01(\x02\x12!\n\x19\x64\x65stination_obj_unique_id\x18\x12 \x01(\x05\x12\x30\n\x0fstart_link_info\x18\x13 \x01(\x0b\x32\x17.morai_sim_api.LinkInfo\x12.\n\rend_link_info\x18\x14 \x01(\x0b\x32\x17.morai_sim_api.LinkInfo\x12>\n\x11lateral_bias_mode\x18\x15 \x01(\x0e\x32#.morai_sim_api.BiasMode.LatBiasMode\x12\x18\n\x10min_lateral_bias\x18\x16 \x01(\x02\x12\x18\n\x10max_lateral_bias\x18\x17 \x01(\x02\"y\n\rSetSpawnPoint\x12\x11\n\tunique_id\x18\x01 \x01(\t\x12+\n\x04info\x18\x02 \x01(\x0b\x32\x1d.morai_sim_api.SpawnPointInfo\x12\x19\n\x11spawn_object_name\x18\x03 \x01(\t\x12\r\n\x05pause\x18\x04 \x01(\x08\"C\n\x11SetSpawnPointList\x12.\n\x08req_list\x18\x01 \x03(\x0b\x32\x1c.morai_sim_api.SetSpawnPoint\"\x90\x01\n\x0eVehicleLimiter\x12\x14\n\x0climiter_type\x18\x01 \x01(\x05\x12\x16\n\x0emin_saturation\x18\x02 \x01(\x02\x12\x16\n\x0emax_saturation\x18\x03 \x01(\x02\x12\x14\n\x0c\x66\x61lling_rate\x18\x04 \x01(\x02\x12\x13\n\x0brising_rate\x18\x05 \x01(\x02\x12\r\n\x05reset\x18\x06 \x01(\x08\"6\n\x13VehicleControlState\x12\r\n\x05steer\x18\x01 \x01(\x02\x12\x10\n\x08velocity\x18\x02 \x01(\x02\"\x92\x02\n\x0fVehicleDynamics\x12\x39\n\rdynamics_type\x18\x01 \x01(\x0e\x32\".morai_sim_api.VehicleDynamicsType\x12\x34\n\x05steer\x18\x02 \x01(\x0b\x32#.morai_sim_api.VehicleDynamicsSteerH\x00\x12?\n\x0bspeed_limit\x18\x03 \x01(\x0b\x32(.morai_sim_api.VehicleDynamicsSpeedLimitH\x00\x12\x32\n\x04mass\x18\x04 \x01(\x0b\x32\".morai_sim_api.VehicleDynamicsMassH\x00\x12\r\n\x05reset\x18\x05 \x01(\x08\x42\n\n\x08\x44ynamics\"/\n\x14VehicleDynamicsSteer\x12\x17\n\x0fmax_steer_angle\x18\x01 \x01(\x02\"G\n\x19VehicleDynamicsSpeedLimit\x12\x15\n\rspeed_limiter\x18\x01 \x01(\x08\x12\x13\n\x0bspeed_limit\x18\x02 \x01(\x02\"#\n\x13VehicleDynamicsMass\x12\x0c\n\x04mass\x18\x01 \x01(\x02\"N\n\x10VehicleSpecParam\x12\x13\n\tunique_id\x18\x01 \x01(\tH\x00\x12\x1c\n\x12vehicle_model_name\x18\x02 \x01(\tH\x00\x42\x07\n\x05Types\"\x94\x02\n\x0fVehicleSpecData\x12=\n\x0csub_category\x18\x01 \x01(\x0e\x32\'.morai_sim_api.VehicleClass.SUBCATEGORY\x12\x0e\n\x06length\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\x12\x12\n\nwheel_base\x18\x05 \x01(\x02\x12\x16\n\x0e\x66ront_overhang\x18\x06 \x01(\x02\x12\x15\n\rrear_overhang\x18\x07 \x01(\x02\x12\x34\n\x0e\x64ynamics_level\x18\x08 \x03(\x0b\x32\x1c.morai_sim_api.DynamicsLevel\x12\x1a\n\x12max_steering_angle\x18\t \x01(\x02\"8\n\rDynamicsLevel\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x0b\n\x03\x65go\x18\x02 \x01(\t\x12\x0b\n\x03npc\x18\x03 \x01(\t\"Y\n\x0bVehicleSpec\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x39\n\x11vehicle_spec_data\x18\x02 \x01(\x0b\x32\x1e.morai_sim_api.VehicleSpecData*o\n\tActorType\x12\x16\n\x12\x41\x43TOR_TYPE_UNKNOWN\x10\x00\x12\x16\n\x12\x41\x43TOR_TYPE_VEHICLE\x10\x01\x12\x19\n\x15\x41\x43TOR_TYPE_PEDESTRIAN\x10\x02\x12\x17\n\x13\x41\x43TOR_TYPE_OBSTACLE\x10\x03*w\n\x0bVehicleType\x12\x18\n\x14VEHICLE_TYPE_UNKNOWN\x10\x00\x12\x17\n\x13VEHICLE_TYPE_MASTER\x10\x01\x12\x1a\n\x16VEHICLE_TYPE_MULTI_EGO\x10\x02\x12\x19\n\x15VEHICLE_TYPE_SURROUND\x10\x03*\xb5\x01\n\x17VehicleDrivingParamType\x12$\n VEHICLE_DRIVING_PARAM_TYPE_BEGIN\x10\x00\x12\'\n#VEHICLE_DRIVING_PARAM_TYPE_CONSTANT\x10\x01\x12\'\n#VEHICLE_DRIVING_PARAM_TYPE_VARIABLE\x10\x02\x12\"\n\x1eVEHICLE_DRIVING_PARAM_TYPE_END\x10\x03*\x87\x01\n\x13VehicleVelocityType\x12\x17\n\x13VELOCITY_TYPE_BEGIN\x10\x00\x12\x1e\n\x1aVELOCITY_TYPE_LINKVELOCITY\x10\x01\x12 \n\x1cVELOCITY_TYPE_CUSTOMVELOCITY\x10\x02\x12\x15\n\x11VELOCITY_TYPE_END\x10\x03*\xb9\x02\n\x11\x41\x63torPropertyType\x12\x1c\n\x18\x41\x43TOR_PROPERTY_TRANSFORM\x10\x00\x12\x1a\n\x16\x41\x43TOR_PROPERTY_NETWORK\x10\x01\x12\x1a\n\x16\x41\x43TOR_PROPERTY_PHYSICS\x10\x02\x12\x15\n\x11\x41\x43TOR_PROPERTY_AI\x10\x03\x12 \n\x1c\x41\x43TOR_PROPERTY_VEHICLE_EVENT\x10\x04\x12\"\n\x1e\x41\x43TOR_PROPERTY_VEHICLE_LIMITER\x10\x05\x12#\n\x1f\x41\x43TOR_PROPERTY_VEHICLE_DYNAMICS\x10\x06\x12(\n$ACTOR_PROPERTY_VEHICLE_CONTROL_STATE\x10\x07\x12\"\n\x1e\x41\x43TOR_PROPERTY_TRANSFORM_DELTA\x10\x08*n\n\x13VehicleDynamicsType\x12\x1a\n\x16VEHICLE_DYNAMICS_STEER\x10\x00\x12 \n\x1cVEHICLE_DYNAMICS_SPEED_LIMIT\x10\x01\x12\x19\n\x15VEHICLE_DYNAMICS_MASS\x10\x02*p\n\x08GearMode\x12\x0f\n\x0bGEAR_MODE_M\x10\x00\x12\x0f\n\x0bGEAR_MODE_P\x10\x01\x12\x0f\n\x0bGEAR_MODE_R\x10\x02\x12\x0f\n\x0bGEAR_MODE_N\x10\x03\x12\x0f\n\x0bGEAR_MODE_D\x10\x04\x12\x0f\n\x0bGEAR_MODE_L\x10\x05*i\n\x0b\x43RUISE_TYPE\x12\x15\n\x11\x43RUISE_TYPE_BEGIN\x10\x00\x12\x14\n\x10\x43RUISE_TYPE_LINK\x10\x01\x12\x18\n\x14\x43RUISE_TYPE_CONSTANT\x10\x02\x12\x13\n\x0f\x43RUISE_TYPE_END\x10\x03*\xdf\x03\n\x11TrafficLightColor\x12\x12\n\x0eTL_COLOR_BEGIN\x10\x00\x12\x0e\n\nTL_COLOR_R\x10\x01\x12\x0e\n\nTL_COLOR_Y\x10\x04\x12\x0f\n\x0bTL_COLOR_SG\x10\x10\x12\x0f\n\x0bTL_COLOR_LG\x10 \x12\x0f\n\x0bTL_COLOR_RG\x10@\x12\x11\n\x0cTL_COLOR_UTG\x10\x80\x01\x12\x11\n\x0cTL_COLOR_ULG\x10\x80\x02\x12\x11\n\x0cTL_COLOR_URG\x10\x80\x04\x12\x11\n\x0cTL_COLOR_LLG\x10\x80\x08\x12\x11\n\x0cTL_COLOR_LRG\x10\x80\x10\x12\x15\n\x11TL_COLOR_R_WITH_Y\x10\x05\x12\x15\n\x11TL_COLOR_Y_WITH_G\x10\x14\x12\x19\n\x15TL_COLOR_Y_WITH_GLEFT\x10$\x12\x19\n\x15TL_COLOR_G_WITH_GLEFT\x10\x30\x12\x19\n\x15TL_COLOR_R_WITH_GLEFT\x10!\x12\x14\n\x0fTL_COLOR_LLG_SG\x10\x90\x08\x12\x13\n\x0eTL_COLOR_R_LLG\x10\x81\x08\x12\x15\n\x10TL_COLOR_ULG_URG\x10\x80\x06\x12\x1f\n\x12TL_COLOR_UNDEFINED\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\"\n\x15TL_COLOR_NOT_DETECTED\x10\xfe\xff\xff\xff\xff\xff\xff\xff\xff\x01*\x91\x02\n\x0fNetworkCommType\x12\x1b\n\x17NETWORK_COMM_TYPE_BEGIN\x10\x00\x12\x19\n\x15NETWORK_COMM_TYPE_UDP\x10\x01\x12\x19\n\x15NETWORK_COMM_TYPE_TCP\x10\x02\x12\x19\n\x15NETWORK_COMM_TYPE_ROS\x10\x03\x12\x19\n\x15NETWORK_COMM_TYPE_LCM\x10\x04\x12\x1c\n\x18NETWORK_COMM_TYPE_SERIAL\x10\x05\x12\x1e\n\x1aNETWORK_COMM_TYPE_ROS_AUTO\x10\x06\x12\x1c\n\x18NETWORK_COMM_TYPE_APOLLO\x10\x07\x12\x19\n\x15NETWORK_COMM_TYPE_END\x10\x08*\xa0\x06\n\x0fNetworkItemType\x12\x1b\n\x17NETWORK_ITEM_TYPE_BEGIN\x10\x00\x12\x1d\n\x19NETWORK_ITEM_TYPE_HOST_IP\x10\x01\x12$\n NETWORK_ITEM_TYPE_DESTINATION_IP\x10\x02\x12\x1f\n\x1bNETWORK_ITEM_TYPE_BRIDGE_IP\x10\x03\x12\x1f\n\x1bNETWORK_ITEM_TYPE_HOST_PORT\x10\x04\x12&\n\"NETWORK_ITEM_TYPE_DESTINATION_PORT\x10\x05\x12!\n\x1dNETWORK_ITEM_TYPE_BRIDGE_PORT\x10\x06\x12\"\n\x1eNETWORK_ITEM_TYPE_MESSAGE_TYPE\x10\x07\x12#\n\x1fNETWORK_ITEM_TYPE_MESSAGE_TOPIC\x10\x08\x12%\n!NETWORK_ITEM_TYPE_MESSAGE_CHANNEL\x10\t\x12\"\n\x1eNETWORK_ITEM_TYPE_SERIAL_FIELD\x10\n\x12\'\n#NETWORK_ITEM_TYPE_SERIAL_PORTNUMBER\x10\x0b\x12%\n!NETWORK_ITEM_TYPE_SERIAL_BAUDRATE\x10\x0c\x12#\n\x1fNETWORK_ITEM_TYPE_SERIAL_PARITY\x10\r\x12%\n!NETWORK_ITEM_TYPE_SERIAL_DATABITS\x10\x0e\x12%\n!NETWORK_ITEM_TYPE_SERIAL_STOPBITS\x10\x0f\x12(\n$NETWORK_ITEM_TYPE_SERIAL_FLOWCONTROL\x10\x10\x12\"\n\x1eNETWORK_ITEM_TYPE_SERVCIE_NAME\x10\x11\x12\x19\n\x15NETWORK_ITEM_TYPE_SRV\x10\x12\x12\x1e\n\x1aNETWORK_ITEM_TYPE_FRAME_ID\x10\x13\x12#\n\x1fNETWORK_ITEM_TYPE_CHILDFRAME_ID\x10\x14\x12\x19\n\x15NETWORK_ITEM_TYPE_END\x10\x15*\xc3(\n\x0bPUBSUB_TYPE\x12\x15\n\x11PUBSUB_TYPE_BEGIN\x10\x00\x12\x17\n\x12PUBSUB_TYPE_Common\x10\x80\x02\x12$\n\x1fPUBSUB_TYPE_ObjectInfoPublisher\x10\x81\x02\x12\"\n\x1dPUBSUB_TYPE_TLStatusPublisher\x10\x82\x02\x12!\n\x1cPUBSUB_TYPE_TLCtrlSubscriber\x10\x83\x02\x12)\n$PUBSUB_TYPE_MultiEgoTransformHandler\x10\x84\x02\x12\x1e\n\x19PUBSUB_TYPE_CollisionData\x10\x85\x02\x12$\n\x1fPUBSUB_TYPE_SensorPosSubscriber\x10\x86\x02\x12,\n\'PUBSUB_TYPE_GlobalIntersectionPublisher\x10\x87\x02\x12.\n)PUBSUB_TYPE_IntersectionControlSubscriber\x10\x88\x02\x12,\n\'PUBSUB_TYPE_IntersectionStatusPublisher\x10\x89\x02\x12)\n$PUBSUB_TYPE_SensorSyncDataSubscriber\x10\x8a\x02\x12\x1d\n\x18PUBSUB_TYPE_TF2Publisher\x10\x8b\x02\x12.\n)PUBSUB_TYPE_VehicleCollisionInfoPublisher\x10\x8c\x02\x12+\n&PUBSUB_TYPE_SyncModeCmdServiceProvider\x10\x8d\x02\x12\x33\n.PUBSUB_TYPE_SyncModeWaitForTickServiceProvider\x10\x8e\x02\x12&\n!PUBSUB_TYPE_SyncModeInfoPublisher\x10\x8f\x02\x12,\n\'PUBSUB_TYPE_SyncModeAddObjectSubscriber\x10\x90\x02\x12/\n*PUBSUB_TYPE_SyncModeRemoveObjectSubscriber\x10\x91\x02\x12/\n*PUBSUB_TYPE_SyncModeSetGearServiceProvider\x10\x92\x02\x12/\n*PUBSUB_TYPE_SyncModeCtrlCmdServiceProvider\x10\x93\x02\x12\x36\n1PUBSUB_TYPE_SyncModeSaveSensorDataServiceProvider\x10\x94\x02\x12/\n*PUBSUB_TYPE_SyncModeMoraiSLServiceProvider\x10\x95\x02\x12)\n$PUBSUB_TYPE_MandoObjectInfoPublisher\x10\x96\x02\x12\'\n\"PUBSUB_TYPE_HILSMoraiInfoPublisher\x10\x97\x02\x12%\n PUBSUB_TYPE_FaultStatusPublisher\x10\x98\x02\x12-\n(PUBSUB_TYPE_FaultStatusVehicleSubscriber\x10\x99\x02\x12&\n!PUBSUB_TYPE_AutoeverIFSSubscriber\x10\x9a\x02\x12+\n&PUBSUB_TYPE_FaultStatusWheelSubscriber\x10\x9b\x02\x12,\n\'PUBSUB_TYPE_FaultStatusSensorSubscriber\x10\x9c\x02\x12\'\n\"PUBSUB_TYPE_AutoeverInfoSubscriber\x10\x9d\x02\x12\x14\n\x0fPUBSUB_TYPE_ERP\x10\x80\x04\x12!\n\x1cPUBSUB_TYPE_ERPInfoPublisher\x10\x81\x04\x12\'\n\"PUBSUB_TYPE_ERPSerialInfoPublisher\x10\x82\x04\x12!\n\x1cPUBSUB_TYPE_ERPCmdController\x10\x83\x04\x12\'\n\"PUBSUB_TYPE_ERPObjectInfoPublisher\x10\x84\x04\x12\x16\n\x11PUBSUB_TYPE_MORAI\x10\x80\x06\x12+\n&PUBSUB_TYPE_MoraiAutowareInfoPublisher\x10\x81\x06\x12#\n\x1ePUBSUB_TYPE_MoraiInfoPublisher\x10\x82\x06\x12#\n\x1ePUBSUB_TYPE_MoraiCmdController\x10\x83\x06\x12)\n$PUBSUB_TYPE_MoraiObjectInfoPublisher\x10\x84\x06\x12-\n(PUBSUB_TYPE_MoraiSimProcHandleSubscriber\x10\x85\x06\x12,\n\'PUBSUB_TYPE_MoraiSimProcStatusPublisher\x10\x86\x06\x12\'\n\"PUBSUB_TYPE_MoraiSLServiceProvider\x10\x87\x06\x12%\n PUBSUB_TYPE_MoraiLampsSubscriber\x10\x88\x06\x12,\n\'PUBSUB_TYPE_MoraiSimProcServiceProvider\x10\x89\x06\x12\'\n\"PUBSUB_TYPE_MoraiTLServiceProvider\x10\x8a\x06\x12)\n$PUBSUB_TYPE_MoraiReplayInfoPublisher\x10\x8b\x06\x12-\n(PUBSUB_TYPE_MoraiEventCmdServiceProvider\x10\x8c\x06\x12\x30\n+PUBSUB_TYPE_MoraiVehicleSpecServiceProvider\x10\x8d\x06\x12,\n\'PUBSUB_TYPE_MoraiMapSpecServiceProvider\x10\x8e\x06\x12\"\n\x1dPUBSUB_TYPE_MoraiSLSubscriber\x10\x8f\x06\x12\x19\n\x14PUBSUB_TYPE_AUTOWARE\x10\x80\x08\x12+\n&PUBSUB_TYPE_MoraiAutowareCmdController\x10\x81\x08\x12\"\n\x1dPUBSUB_TYPE_MoraiAutowareGear\x10\x82\x08\x12\x16\n\x11PUBSUB_TYPE_NAVER\x10\x80\n\x12\"\n\x1dPUBSUB_TYPE_NaverSLSubscriber\x10\x81\n\x12-\n(PUBSUB_TYPE_NaverSimProcHandleSubscriber\x10\x82\n\x12\x37\n2PUBSUB_TYPE_NaverInfoPublisher_ObdAcceleratorPedal\x10\x83\n\x12+\n&PUBSUB_TYPE_NaverInfoPublisher_ObdGear\x10\x84\n\x12,\n\'PUBSUB_TYPE_NaverInfoPublisher_ObdLamps\x10\x85\n\x12\x34\n/PUBSUB_TYPE_NaverInfoPublisher_ObdSteeringAngle\x10\x86\n\x12\x32\n-PUBSUB_TYPE_NaverInfoPublisher_ObdWheelSpeeds\x10\x87\n\x12.\n)PUBSUB_TYPE_NaverInfoPublisher_ObdYawRate\x10\x88\n\x12/\n*PUBSUB_TYPE_NaverInfoPublisher_VehiclePose\x10\x89\n\x12)\n$PUBSUB_TYPE_NaverObjectInfoPublisher\x10\x8a\n\x12,\n\'PUBSUB_TYPE_NaverSimProcStatusPublisher\x10\x8b\n\x12+\n&PUBSUB_TYPE_NaverTrafficLightPublisher\x10\x8c\n\x12#\n\x1ePUBSUB_TYPE_NaverCmdController\x10\x8d\n\x12)\n$PUBSUB_TYPE_NaverSubscriber_ObdLamps\x10\x8e\n\x12\'\n\"PUBSUB_TYPE_NaverSLServiceProvider\x10\x8f\n\x12,\n\'PUBSUB_TYPE_NaverSimProcServiceProvider\x10\x90\n\x12\'\n\"PUBSUB_TYPE_NaverTLServiceProvider\x10\x91\n\x12\x15\n\x10PUBSUB_TYPE_CBNU\x10\x80\x0c\x12!\n\x1cPUBSUB_TYPE_CBNUSLSubscriber\x10\x81\x0c\x12\"\n\x1dPUBSUB_TYPE_CBNUCmdController\x10\x82\x0c\x12\"\n\x1dPUBSUB_TYPE_CBNUInfoPublisher\x10\x83\x0c\x12(\n#PUBSUB_TYPE_CBNUObjectInfoPublisher\x10\x84\x0c\x12\x16\n\x11PUBSUB_TYPE_KAIST\x10\x80\x0e\x12\"\n\x1dPUBSUB_TYPE_KaistSLSubscriber\x10\x81\x0e\x12#\n\x1ePUBSUB_TYPE_KaistCmdController\x10\x82\x0e\x12#\n\x1ePUBSUB_TYPE_KaistInfoPublisher\x10\x83\x0e\x12)\n$PUBSUB_TYPE_KaistObjectInfoPublisher\x10\x84\x0e\x12\x16\n\x11PUBSUB_TYPE_WECAR\x10\x80\x10\x12#\n\x1ePUBSUB_TYPE_WeCarCmdController\x10\x81\x10\x12#\n\x1ePUBSUB_TYPE_WeCarInfoPublisher\x10\x82\x10\x12,\n\'PUBSUB_TYPE_WeCarInfoVescStatePublisher\x10\x83\x10\x12(\n#PUBSUB_TYPE_WeCarInfoSteerPublisher\x10\x84\x10\x12\x16\n\x11PUBSUB_TYPE_SSAFY\x10\x80\x12\x12#\n\x1ePUBSUB_TYPE_SSAFYCmdController\x10\x81\x12\x12,\n\'PUBSUB_TYPE_SSAFYTurtleBotInfoPublisher\x10\x82\x12\x12+\n&PUBSUB_TYPE_SSAFYObjectStatusPublisher\x10\x83\x12\x12-\n(PUBSUB_TYPE_SSAFYObjectControlSubscriber\x10\x84\x12\x12-\n(PUBSUB_TYPE_SSAFYEnviromentInfoPublisher\x10\x85\x12\x12\x32\n-PUBSUB_TYPE_SSAFYStuffObjectControlSubscriber\x10\x86\x12\x12.\n)PUBSUB_TYPE_SSAFYStuffObjectInfoPublisher\x10\x87\x12\x12\x1b\n\x16PUBSUB_TYPE_KAISTGHOST\x10\x80\x14\x12(\n#PUBSUB_TYPE_KaistGhostCmdController\x10\x81\x14\x12\x1b\n\x16PUBSUB_TYPE_MORAIGHOST\x10\x80\x16\x12(\n#PUBSUB_TYPE_MoraiGhostCmdController\x10\x81\x16\x12(\n#PUBSUB_TYPE_MoraiNpcGhostController\x10\x82\x16\x12\x1a\n\x15PUBSUB_TYPE_SCOUTMINI\x10\x80\x18\x12#\n\x1ePUBSUB_TYPE_ScoutCmdController\x10\x81\x18\x12#\n\x1ePUBSUB_TYPE_ScoutInfoPublisher\x10\x82\x18\x12(\n#PUBSUB_TYPE_ScoutLightCmdSubscriber\x10\x83\x18\x12\x16\n\x11PUBSUB_TYPE_CYBER\x10\x80\x1a\x12#\n\x1ePUBSUB_TYPE_CyberCmdController\x10\x81\x1a\x12&\n!PUBSUB_TYPE_CyberChassisPublisher\x10\x82\x1a\x12\'\n\"PUBSUB_TYPE_CyberBestPosePublisher\x10\x83\x1a\x12&\n!PUBSUB_TYPE_CyberInsStatPublisher\x10\x84\x1a\x12\'\n\"PUBSUB_TYPE_CyberOdometryPublisher\x10\x85\x1a\x12+\n&PUBSUB_TYPE_CyberCorrectedImuPublisher\x10\x86\x1a\x12\"\n\x1dPUBSUB_TYPE_CyberImuPublisher\x10\x87\x1a\x12\x16\n\x11PUBSUB_TYPE_ERPV2\x10\x80\x1c\x12#\n\x1ePUBSUB_TYPE_ERPv2CmdController\x10\x81\x1c\x12#\n\x1ePUBSUB_TYPE_ERPv2InfoPublisher\x10\x82\x1c\x12)\n$PUBSUB_TYPE_ERPv2ObjectInfoPublisher\x10\x83\x1c\x12)\n$PUBSUB_TYPE_ERPv2SerialInfoPublisher\x10\x84\x1c\x12\x16\n\x11PUBSUB_TYPE_WEBOT\x10\x80\x1e\x12#\n\x1ePUBSUB_TYPE_WeBOTCmdController\x10\x81\x1e\x12(\n#PUBSUB_TYPE_WeBOTInfoSteerPublisher\x10\x82\x1e\x12,\n\'PUBSUB_TYPE_WeBOTInfoVescStatePublisher\x10\x83\x1e\x12\x13\n\x0ePUBSUB_TYPE_PR\x10\x80 \x12 \n\x1bPUBSUB_TYPE_PRCmdController\x10\x81 \x12\"\n\x1dPUBSUB_TYPE_PRStatusPublisher\x10\x82 \x12\'\n\"PUBSUB_TYPE_PREventServiceProvider\x10\x83 \x12\"\n\x1dPUBSUB_TYPE_DIFFERETIAL_DRIVE\x10\x80\"\x12%\n PUBSUB_TYPE_MoraiDdCmdController\x10\x81\"\x12%\n PUBSUB_TYPE_MoraiDdInfoPublisher\x10\x82\"\x12\x14\n\x0fPUBSUB_TYPE_END\x10\x83\"*\xae\x01\n\x11NetworkConnetType\x12\x1e\n\x1aNETWORK_CONNECT_TYPE_BEGIN\x10\x00\x12\x1c\n\x18NETWORK_CONNECT_TYPE_EGO\x10\x01\x12\x1f\n\x1bNETWORK_CONNECT_TYPE_PUBSUB\x10\x02\x12\x1c\n\x18NETWORK_CONNECT_TYPE_SIM\x10\x03\x12\x1c\n\x18NETWORK_CONNECT_TYPE_END\x10\x04\x32\xcc\x0e\n\nMoraiActor\x12<\n\x06SetEgo\x12\x19.morai_sim_api.EgoCtrlCmd\x1a\x15.morai_sim_api.Result\"\x00\x12N\n\nSpawnActor\x12\x1f.morai_sim_api.SpawnActorParams\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12M\n\x13GetActorStateStream\x12\x16.google.protobuf.Empty\x1a\x1a.morai_sim_api.ActorStates\"\x00\x30\x01\x12\x46\n\rGetActorState\x12\x18.morai_sim_api.ActorInfo\x1a\x19.morai_sim_api.ActorState\"\x00\x12[\n\x16GetActorNetworkSetting\x12\x18.morai_sim_api.ActorInfo\x1a%.morai_sim_api.NetworkProtocolSetting\"\x00\x12\x41\n\x0c\x44\x65stroyActor\x12\x18.morai_sim_api.ActorInfo\x1a\x15.morai_sim_api.Result\"\x00\x12\x43\n\x10\x44\x65stroyAllActors\x12\x16.google.protobuf.Empty\x1a\x15.morai_sim_api.Result\"\x00\x12\x46\n\rWalkerControl\x12\x1c.morai_sim_api.WalkerCtrlCmd\x1a\x15.morai_sim_api.Result\"\x00\x12H\n\x0eVehicleControl\x12\x1d.morai_sim_api.VehicleCtrlCmd\x1a\x15.morai_sim_api.Result\"\x00\x12G\n\x0fSetVehicleRoute\x12\x1b.morai_sim_api.VehicleRoute\x1a\x15.morai_sim_api.Result\"\x00\x12S\n\x15SetVehicleDestination\x12!.morai_sim_api.VehicleDestination\x1a\x15.morai_sim_api.Result\"\x00\x12I\n\x10SetActorProperty\x12\x1c.morai_sim_api.ActorProperty\x1a\x15.morai_sim_api.Result\"\x00\x12M\n\x19GetTrafficLightInfoByLink\x12\x17.morai_sim_api.LinkInfo\x1a\x15.morai_sim_api.TLInfo\"\x00\x12O\n\x18GetTrafficLightInfoByUid\x12\x1a.morai_sim_api.StringValue\x1a\x15.morai_sim_api.TLInfo\"\x00\x12J\n\x0fGetIntscnTLInfo\x12\x1a.morai_sim_api.StringValue\x1a\x19.morai_sim_api.TLInfoList\"\x00\x12X\n\x14SetTrafficLightState\x12\x1f.morai_sim_api.TLStateParamList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12\\\n\x14SetIntersectionState\x12#.morai_sim_api.IntscnStateParamList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12\x62\n\x17SetIntersectionSchedule\x12&.morai_sim_api.IntscnScheduleParamList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12X\n\x0eSetDisturbance\x12%.morai_sim_api.DisturbanceVehicleList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12X\n\x10\x43reateSpawnPoint\x12#.morai_sim_api.CreateSpawnPointList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12X\n\x10\x45nableSpawnPoint\x12#.morai_sim_api.EnableSpawnPointList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12R\n\rSetSpawnPoint\x12 .morai_sim_api.SetSpawnPointList\x1a\x1d.morai_sim_api.ActorResponses\"\x00\x12O\n\x0eGetVehicleSpec\x12\x1f.morai_sim_api.VehicleSpecParam\x1a\x1a.morai_sim_api.VehicleSpec\"\x00\x42&H\x01\xaa\x02!CoreLib.Grpc.Protobuf.MoraiSimAPIb\x06proto3')

_ACTORTYPE = DESCRIPTOR.enum_types_by_name['ActorType']
ActorType = enum_type_wrapper.EnumTypeWrapper(_ACTORTYPE)
_VEHICLETYPE = DESCRIPTOR.enum_types_by_name['VehicleType']
VehicleType = enum_type_wrapper.EnumTypeWrapper(_VEHICLETYPE)
_VEHICLEDRIVINGPARAMTYPE = DESCRIPTOR.enum_types_by_name['VehicleDrivingParamType']
VehicleDrivingParamType = enum_type_wrapper.EnumTypeWrapper(_VEHICLEDRIVINGPARAMTYPE)
_VEHICLEVELOCITYTYPE = DESCRIPTOR.enum_types_by_name['VehicleVelocityType']
VehicleVelocityType = enum_type_wrapper.EnumTypeWrapper(_VEHICLEVELOCITYTYPE)
_ACTORPROPERTYTYPE = DESCRIPTOR.enum_types_by_name['ActorPropertyType']
ActorPropertyType = enum_type_wrapper.EnumTypeWrapper(_ACTORPROPERTYTYPE)
_VEHICLEDYNAMICSTYPE = DESCRIPTOR.enum_types_by_name['VehicleDynamicsType']
VehicleDynamicsType = enum_type_wrapper.EnumTypeWrapper(_VEHICLEDYNAMICSTYPE)
_GEARMODE = DESCRIPTOR.enum_types_by_name['GearMode']
GearMode = enum_type_wrapper.EnumTypeWrapper(_GEARMODE)
_CRUISE_TYPE = DESCRIPTOR.enum_types_by_name['CRUISE_TYPE']
CRUISE_TYPE = enum_type_wrapper.EnumTypeWrapper(_CRUISE_TYPE)
_TRAFFICLIGHTCOLOR = DESCRIPTOR.enum_types_by_name['TrafficLightColor']
TrafficLightColor = enum_type_wrapper.EnumTypeWrapper(_TRAFFICLIGHTCOLOR)
_NETWORKCOMMTYPE = DESCRIPTOR.enum_types_by_name['NetworkCommType']
NetworkCommType = enum_type_wrapper.EnumTypeWrapper(_NETWORKCOMMTYPE)
_NETWORKITEMTYPE = DESCRIPTOR.enum_types_by_name['NetworkItemType']
NetworkItemType = enum_type_wrapper.EnumTypeWrapper(_NETWORKITEMTYPE)
_PUBSUB_TYPE = DESCRIPTOR.enum_types_by_name['PUBSUB_TYPE']
PUBSUB_TYPE = enum_type_wrapper.EnumTypeWrapper(_PUBSUB_TYPE)
_NETWORKCONNETTYPE = DESCRIPTOR.enum_types_by_name['NetworkConnetType']
NetworkConnetType = enum_type_wrapper.EnumTypeWrapper(_NETWORKCONNETTYPE)
ACTOR_TYPE_UNKNOWN = 0
ACTOR_TYPE_VEHICLE = 1
ACTOR_TYPE_PEDESTRIAN = 2
ACTOR_TYPE_OBSTACLE = 3
VEHICLE_TYPE_UNKNOWN = 0
VEHICLE_TYPE_MASTER = 1
VEHICLE_TYPE_MULTI_EGO = 2
VEHICLE_TYPE_SURROUND = 3
VEHICLE_DRIVING_PARAM_TYPE_BEGIN = 0
VEHICLE_DRIVING_PARAM_TYPE_CONSTANT = 1
VEHICLE_DRIVING_PARAM_TYPE_VARIABLE = 2
VEHICLE_DRIVING_PARAM_TYPE_END = 3
VELOCITY_TYPE_BEGIN = 0
VELOCITY_TYPE_LINKVELOCITY = 1
VELOCITY_TYPE_CUSTOMVELOCITY = 2
VELOCITY_TYPE_END = 3
ACTOR_PROPERTY_TRANSFORM = 0
ACTOR_PROPERTY_NETWORK = 1
ACTOR_PROPERTY_PHYSICS = 2
ACTOR_PROPERTY_AI = 3
ACTOR_PROPERTY_VEHICLE_EVENT = 4
ACTOR_PROPERTY_VEHICLE_LIMITER = 5
ACTOR_PROPERTY_VEHICLE_DYNAMICS = 6
ACTOR_PROPERTY_VEHICLE_CONTROL_STATE = 7
ACTOR_PROPERTY_TRANSFORM_DELTA = 8
VEHICLE_DYNAMICS_STEER = 0
VEHICLE_DYNAMICS_SPEED_LIMIT = 1
VEHICLE_DYNAMICS_MASS = 2
GEAR_MODE_M = 0
GEAR_MODE_P = 1
GEAR_MODE_R = 2
GEAR_MODE_N = 3
GEAR_MODE_D = 4
GEAR_MODE_L = 5
CRUISE_TYPE_BEGIN = 0
CRUISE_TYPE_LINK = 1
CRUISE_TYPE_CONSTANT = 2
CRUISE_TYPE_END = 3
TL_COLOR_BEGIN = 0
TL_COLOR_R = 1
TL_COLOR_Y = 4
TL_COLOR_SG = 16
TL_COLOR_LG = 32
TL_COLOR_RG = 64
TL_COLOR_UTG = 128
TL_COLOR_ULG = 256
TL_COLOR_URG = 512
TL_COLOR_LLG = 1024
TL_COLOR_LRG = 2048
TL_COLOR_R_WITH_Y = 5
TL_COLOR_Y_WITH_G = 20
TL_COLOR_Y_WITH_GLEFT = 36
TL_COLOR_G_WITH_GLEFT = 48
TL_COLOR_R_WITH_GLEFT = 33
TL_COLOR_LLG_SG = 1040
TL_COLOR_R_LLG = 1025
TL_COLOR_ULG_URG = 768
TL_COLOR_UNDEFINED = -1
TL_COLOR_NOT_DETECTED = -2
NETWORK_COMM_TYPE_BEGIN = 0
NETWORK_COMM_TYPE_UDP = 1
NETWORK_COMM_TYPE_TCP = 2
NETWORK_COMM_TYPE_ROS = 3
NETWORK_COMM_TYPE_LCM = 4
NETWORK_COMM_TYPE_SERIAL = 5
NETWORK_COMM_TYPE_ROS_AUTO = 6
NETWORK_COMM_TYPE_APOLLO = 7
NETWORK_COMM_TYPE_END = 8
NETWORK_ITEM_TYPE_BEGIN = 0
NETWORK_ITEM_TYPE_HOST_IP = 1
NETWORK_ITEM_TYPE_DESTINATION_IP = 2
NETWORK_ITEM_TYPE_BRIDGE_IP = 3
NETWORK_ITEM_TYPE_HOST_PORT = 4
NETWORK_ITEM_TYPE_DESTINATION_PORT = 5
NETWORK_ITEM_TYPE_BRIDGE_PORT = 6
NETWORK_ITEM_TYPE_MESSAGE_TYPE = 7
NETWORK_ITEM_TYPE_MESSAGE_TOPIC = 8
NETWORK_ITEM_TYPE_MESSAGE_CHANNEL = 9
NETWORK_ITEM_TYPE_SERIAL_FIELD = 10
NETWORK_ITEM_TYPE_SERIAL_PORTNUMBER = 11
NETWORK_ITEM_TYPE_SERIAL_BAUDRATE = 12
NETWORK_ITEM_TYPE_SERIAL_PARITY = 13
NETWORK_ITEM_TYPE_SERIAL_DATABITS = 14
NETWORK_ITEM_TYPE_SERIAL_STOPBITS = 15
NETWORK_ITEM_TYPE_SERIAL_FLOWCONTROL = 16
NETWORK_ITEM_TYPE_SERVCIE_NAME = 17
NETWORK_ITEM_TYPE_SRV = 18
NETWORK_ITEM_TYPE_FRAME_ID = 19
NETWORK_ITEM_TYPE_CHILDFRAME_ID = 20
NETWORK_ITEM_TYPE_END = 21
PUBSUB_TYPE_BEGIN = 0
PUBSUB_TYPE_Common = 256
PUBSUB_TYPE_ObjectInfoPublisher = 257
PUBSUB_TYPE_TLStatusPublisher = 258
PUBSUB_TYPE_TLCtrlSubscriber = 259
PUBSUB_TYPE_MultiEgoTransformHandler = 260
PUBSUB_TYPE_CollisionData = 261
PUBSUB_TYPE_SensorPosSubscriber = 262
PUBSUB_TYPE_GlobalIntersectionPublisher = 263
PUBSUB_TYPE_IntersectionControlSubscriber = 264
PUBSUB_TYPE_IntersectionStatusPublisher = 265
PUBSUB_TYPE_SensorSyncDataSubscriber = 266
PUBSUB_TYPE_TF2Publisher = 267
PUBSUB_TYPE_VehicleCollisionInfoPublisher = 268
PUBSUB_TYPE_SyncModeCmdServiceProvider = 269
PUBSUB_TYPE_SyncModeWaitForTickServiceProvider = 270
PUBSUB_TYPE_SyncModeInfoPublisher = 271
PUBSUB_TYPE_SyncModeAddObjectSubscriber = 272
PUBSUB_TYPE_SyncModeRemoveObjectSubscriber = 273
PUBSUB_TYPE_SyncModeSetGearServiceProvider = 274
PUBSUB_TYPE_SyncModeCtrlCmdServiceProvider = 275
PUBSUB_TYPE_SyncModeSaveSensorDataServiceProvider = 276
PUBSUB_TYPE_SyncModeMoraiSLServiceProvider = 277
PUBSUB_TYPE_MandoObjectInfoPublisher = 278
PUBSUB_TYPE_HILSMoraiInfoPublisher = 279
PUBSUB_TYPE_FaultStatusPublisher = 280
PUBSUB_TYPE_FaultStatusVehicleSubscriber = 281
PUBSUB_TYPE_AutoeverIFSSubscriber = 282
PUBSUB_TYPE_FaultStatusWheelSubscriber = 283
PUBSUB_TYPE_FaultStatusSensorSubscriber = 284
PUBSUB_TYPE_AutoeverInfoSubscriber = 285
PUBSUB_TYPE_ERP = 512
PUBSUB_TYPE_ERPInfoPublisher = 513
PUBSUB_TYPE_ERPSerialInfoPublisher = 514
PUBSUB_TYPE_ERPCmdController = 515
PUBSUB_TYPE_ERPObjectInfoPublisher = 516
PUBSUB_TYPE_MORAI = 768
PUBSUB_TYPE_MoraiAutowareInfoPublisher = 769
PUBSUB_TYPE_MoraiInfoPublisher = 770
PUBSUB_TYPE_MoraiCmdController = 771
PUBSUB_TYPE_MoraiObjectInfoPublisher = 772
PUBSUB_TYPE_MoraiSimProcHandleSubscriber = 773
PUBSUB_TYPE_MoraiSimProcStatusPublisher = 774
PUBSUB_TYPE_MoraiSLServiceProvider = 775
PUBSUB_TYPE_MoraiLampsSubscriber = 776
PUBSUB_TYPE_MoraiSimProcServiceProvider = 777
PUBSUB_TYPE_MoraiTLServiceProvider = 778
PUBSUB_TYPE_MoraiReplayInfoPublisher = 779
PUBSUB_TYPE_MoraiEventCmdServiceProvider = 780
PUBSUB_TYPE_MoraiVehicleSpecServiceProvider = 781
PUBSUB_TYPE_MoraiMapSpecServiceProvider = 782
PUBSUB_TYPE_MoraiSLSubscriber = 783
PUBSUB_TYPE_AUTOWARE = 1024
PUBSUB_TYPE_MoraiAutowareCmdController = 1025
PUBSUB_TYPE_MoraiAutowareGear = 1026
PUBSUB_TYPE_NAVER = 1280
PUBSUB_TYPE_NaverSLSubscriber = 1281
PUBSUB_TYPE_NaverSimProcHandleSubscriber = 1282
PUBSUB_TYPE_NaverInfoPublisher_ObdAcceleratorPedal = 1283
PUBSUB_TYPE_NaverInfoPublisher_ObdGear = 1284
PUBSUB_TYPE_NaverInfoPublisher_ObdLamps = 1285
PUBSUB_TYPE_NaverInfoPublisher_ObdSteeringAngle = 1286
PUBSUB_TYPE_NaverInfoPublisher_ObdWheelSpeeds = 1287
PUBSUB_TYPE_NaverInfoPublisher_ObdYawRate = 1288
PUBSUB_TYPE_NaverInfoPublisher_VehiclePose = 1289
PUBSUB_TYPE_NaverObjectInfoPublisher = 1290
PUBSUB_TYPE_NaverSimProcStatusPublisher = 1291
PUBSUB_TYPE_NaverTrafficLightPublisher = 1292
PUBSUB_TYPE_NaverCmdController = 1293
PUBSUB_TYPE_NaverSubscriber_ObdLamps = 1294
PUBSUB_TYPE_NaverSLServiceProvider = 1295
PUBSUB_TYPE_NaverSimProcServiceProvider = 1296
PUBSUB_TYPE_NaverTLServiceProvider = 1297
PUBSUB_TYPE_CBNU = 1536
PUBSUB_TYPE_CBNUSLSubscriber = 1537
PUBSUB_TYPE_CBNUCmdController = 1538
PUBSUB_TYPE_CBNUInfoPublisher = 1539
PUBSUB_TYPE_CBNUObjectInfoPublisher = 1540
PUBSUB_TYPE_KAIST = 1792
PUBSUB_TYPE_KaistSLSubscriber = 1793
PUBSUB_TYPE_KaistCmdController = 1794
PUBSUB_TYPE_KaistInfoPublisher = 1795
PUBSUB_TYPE_KaistObjectInfoPublisher = 1796
PUBSUB_TYPE_WECAR = 2048
PUBSUB_TYPE_WeCarCmdController = 2049
PUBSUB_TYPE_WeCarInfoPublisher = 2050
PUBSUB_TYPE_WeCarInfoVescStatePublisher = 2051
PUBSUB_TYPE_WeCarInfoSteerPublisher = 2052
PUBSUB_TYPE_SSAFY = 2304
PUBSUB_TYPE_SSAFYCmdController = 2305
PUBSUB_TYPE_SSAFYTurtleBotInfoPublisher = 2306
PUBSUB_TYPE_SSAFYObjectStatusPublisher = 2307
PUBSUB_TYPE_SSAFYObjectControlSubscriber = 2308
PUBSUB_TYPE_SSAFYEnviromentInfoPublisher = 2309
PUBSUB_TYPE_SSAFYStuffObjectControlSubscriber = 2310
PUBSUB_TYPE_SSAFYStuffObjectInfoPublisher = 2311
PUBSUB_TYPE_KAISTGHOST = 2560
PUBSUB_TYPE_KaistGhostCmdController = 2561
PUBSUB_TYPE_MORAIGHOST = 2816
PUBSUB_TYPE_MoraiGhostCmdController = 2817
PUBSUB_TYPE_MoraiNpcGhostController = 2818
PUBSUB_TYPE_SCOUTMINI = 3072
PUBSUB_TYPE_ScoutCmdController = 3073
PUBSUB_TYPE_ScoutInfoPublisher = 3074
PUBSUB_TYPE_ScoutLightCmdSubscriber = 3075
PUBSUB_TYPE_CYBER = 3328
PUBSUB_TYPE_CyberCmdController = 3329
PUBSUB_TYPE_CyberChassisPublisher = 3330
PUBSUB_TYPE_CyberBestPosePublisher = 3331
PUBSUB_TYPE_CyberInsStatPublisher = 3332
PUBSUB_TYPE_CyberOdometryPublisher = 3333
PUBSUB_TYPE_CyberCorrectedImuPublisher = 3334
PUBSUB_TYPE_CyberImuPublisher = 3335
PUBSUB_TYPE_ERPV2 = 3584
PUBSUB_TYPE_ERPv2CmdController = 3585
PUBSUB_TYPE_ERPv2InfoPublisher = 3586
PUBSUB_TYPE_ERPv2ObjectInfoPublisher = 3587
PUBSUB_TYPE_ERPv2SerialInfoPublisher = 3588
PUBSUB_TYPE_WEBOT = 3840
PUBSUB_TYPE_WeBOTCmdController = 3841
PUBSUB_TYPE_WeBOTInfoSteerPublisher = 3842
PUBSUB_TYPE_WeBOTInfoVescStatePublisher = 3843
PUBSUB_TYPE_PR = 4096
PUBSUB_TYPE_PRCmdController = 4097
PUBSUB_TYPE_PRStatusPublisher = 4098
PUBSUB_TYPE_PREventServiceProvider = 4099
PUBSUB_TYPE_DIFFERETIAL_DRIVE = 4352
PUBSUB_TYPE_MoraiDdCmdController = 4353
PUBSUB_TYPE_MoraiDdInfoPublisher = 4354
PUBSUB_TYPE_END = 4355
NETWORK_CONNECT_TYPE_BEGIN = 0
NETWORK_CONNECT_TYPE_EGO = 1
NETWORK_CONNECT_TYPE_PUBSUB = 2
NETWORK_CONNECT_TYPE_SIM = 3
NETWORK_CONNECT_TYPE_END = 4


_SPAWNACTORPARAMS = DESCRIPTOR.message_types_by_name['SpawnActorParams']
_SPAWNACTORPARAM = DESCRIPTOR.message_types_by_name['SpawnActorParam']
_ACTORINFO = DESCRIPTOR.message_types_by_name['ActorInfo']
_ACTORINFOS = DESCRIPTOR.message_types_by_name['ActorInfos']
_ACTORTYPELIST = DESCRIPTOR.message_types_by_name['ActorTypeList']
_VEHICLECTRLCMD = DESCRIPTOR.message_types_by_name['VehicleCtrlCmd']
_WALKERCTRLCMD = DESCRIPTOR.message_types_by_name['WalkerCtrlCmd']
_ACTORSTATES = DESCRIPTOR.message_types_by_name['ActorStates']
_ACTORSTATE = DESCRIPTOR.message_types_by_name['ActorState']
_VEHICLESTATE = DESCRIPTOR.message_types_by_name['VehicleState']
_VEHICLEAUXSTATE = DESCRIPTOR.message_types_by_name['VehicleAuxState']
_VEHICLESPAWNPARAM = DESCRIPTOR.message_types_by_name['VehicleSpawnParam']
_PEDESTRIANSPAWNPARAM = DESCRIPTOR.message_types_by_name['PedestrianSpawnParam']
_OBSTACLESPAWNPARAM = DESCRIPTOR.message_types_by_name['ObstacleSpawnParam']
_ACTORRESPONSE = DESCRIPTOR.message_types_by_name['ActorResponse']
_ACTORRESPONSES = DESCRIPTOR.message_types_by_name['ActorResponses']
_ACTORPROPERTY = DESCRIPTOR.message_types_by_name['ActorProperty']
_NETWORKCONFIG = DESCRIPTOR.message_types_by_name['NetworkConfig']
_NETWORKIPSETTING = DESCRIPTOR.message_types_by_name['NetworkIpSetting']
_NETWORKPROTOCOLSETTING = DESCRIPTOR.message_types_by_name['NetworkProtocolSetting']
_NETWORKPROTOCOLITEM = DESCRIPTOR.message_types_by_name['NetworkProtocolItem']
_NETWORKITEM = DESCRIPTOR.message_types_by_name['NetworkItem']
_TRAFFICLIGHT = DESCRIPTOR.message_types_by_name['TrafficLight']
_TRAFFICLIGHT_TLSCHEDULE = _TRAFFICLIGHT.nested_types_by_name['TLSchedule']
_TRAFFICLIGHT_PSSCHEDULE = _TRAFFICLIGHT.nested_types_by_name['PSSchedule']
_TRAFFICLIGHT_YELLOWSCHEDULE = _TRAFFICLIGHT.nested_types_by_name['YellowSchedule']
_TLINFO = DESCRIPTOR.message_types_by_name['TLInfo']
_TLINFOLIST = DESCRIPTOR.message_types_by_name['TLInfoList']
_TLSTATEPARAM = DESCRIPTOR.message_types_by_name['TLStateParam']
_TLSTATEPARAMLIST = DESCRIPTOR.message_types_by_name['TLStateParamList']
_INTSCNSTATEPARAM = DESCRIPTOR.message_types_by_name['IntscnStateParam']
_INTSCNSTATEPARAMLIST = DESCRIPTOR.message_types_by_name['IntscnStateParamList']
_INTERSECTIONSCHEDULEDATA = DESCRIPTOR.message_types_by_name['IntersectionScheduleData']
_INTSCNSCHEDULEPARAMLIST = DESCRIPTOR.message_types_by_name['IntscnScheduleParamList']
_VEHICLEROUTE = DESCRIPTOR.message_types_by_name['VehicleRoute']
_VEHICLEDESTINATION = DESCRIPTOR.message_types_by_name['VehicleDestination']
_EGOCTRLCMD = DESCRIPTOR.message_types_by_name['EgoCtrlCmd']
_EGOCRUISECTRL = DESCRIPTOR.message_types_by_name['EgoCruiseCtrl']
_VEHICLEEVENTCONTROL = DESCRIPTOR.message_types_by_name['VehicleEventControl']
_DISTURBANCE = DESCRIPTOR.message_types_by_name['Disturbance']
_DISTURBANCEVEHICLE = DESCRIPTOR.message_types_by_name['DisturbanceVehicle']
_DISTURBANCEVEHICLELIST = DESCRIPTOR.message_types_by_name['DisturbanceVehicleList']
_SCENARIOETC = DESCRIPTOR.message_types_by_name['ScenarioETC']
_VEHICLECLASS = DESCRIPTOR.message_types_by_name['VehicleClass']
_BIASMODE = DESCRIPTOR.message_types_by_name['BiasMode']
_CREATESPAWNPOINT = DESCRIPTOR.message_types_by_name['CreateSpawnPoint']
_CREATESPAWNPOINTLIST = DESCRIPTOR.message_types_by_name['CreateSpawnPointList']
_ENABLESPAWNPOINT = DESCRIPTOR.message_types_by_name['EnableSpawnPoint']
_ENABLESPAWNPOINTLIST = DESCRIPTOR.message_types_by_name['EnableSpawnPointList']
_SPAWNPOINTINFO = DESCRIPTOR.message_types_by_name['SpawnPointInfo']
_SETSPAWNPOINT = DESCRIPTOR.message_types_by_name['SetSpawnPoint']
_SETSPAWNPOINTLIST = DESCRIPTOR.message_types_by_name['SetSpawnPointList']
_VEHICLELIMITER = DESCRIPTOR.message_types_by_name['VehicleLimiter']
_VEHICLECONTROLSTATE = DESCRIPTOR.message_types_by_name['VehicleControlState']
_VEHICLEDYNAMICS = DESCRIPTOR.message_types_by_name['VehicleDynamics']
_VEHICLEDYNAMICSSTEER = DESCRIPTOR.message_types_by_name['VehicleDynamicsSteer']
_VEHICLEDYNAMICSSPEEDLIMIT = DESCRIPTOR.message_types_by_name['VehicleDynamicsSpeedLimit']
_VEHICLEDYNAMICSMASS = DESCRIPTOR.message_types_by_name['VehicleDynamicsMass']
_VEHICLESPECPARAM = DESCRIPTOR.message_types_by_name['VehicleSpecParam']
_VEHICLESPECDATA = DESCRIPTOR.message_types_by_name['VehicleSpecData']
_DYNAMICSLEVEL = DESCRIPTOR.message_types_by_name['DynamicsLevel']
_VEHICLESPEC = DESCRIPTOR.message_types_by_name['VehicleSpec']
_DISTURBANCE_LOCATION = _DISTURBANCE.enum_types_by_name['Location']
_DISTURBANCE_TYPE = _DISTURBANCE.enum_types_by_name['Type']
_SCENARIOETC_SUBCATEGORY = _SCENARIOETC.enum_types_by_name['SUBCATEGORY']
_VEHICLECLASS_VEHICLELENGTHTYPE = _VEHICLECLASS.enum_types_by_name['VehicleLengthType']
_VEHICLECLASS_SUBCATEGORY = _VEHICLECLASS.enum_types_by_name['SUBCATEGORY']
_BIASMODE_LATBIASMODE = _BIASMODE.enum_types_by_name['LatBiasMode']
SpawnActorParams = _reflection.GeneratedProtocolMessageType('SpawnActorParams', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNACTORPARAMS,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SpawnActorParams)
  })
_sym_db.RegisterMessage(SpawnActorParams)

SpawnActorParam = _reflection.GeneratedProtocolMessageType('SpawnActorParam', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNACTORPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SpawnActorParam)
  })
_sym_db.RegisterMessage(SpawnActorParam)

ActorInfo = _reflection.GeneratedProtocolMessageType('ActorInfo', (_message.Message,), {
  'DESCRIPTOR' : _ACTORINFO,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorInfo)
  })
_sym_db.RegisterMessage(ActorInfo)

ActorInfos = _reflection.GeneratedProtocolMessageType('ActorInfos', (_message.Message,), {
  'DESCRIPTOR' : _ACTORINFOS,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorInfos)
  })
_sym_db.RegisterMessage(ActorInfos)

ActorTypeList = _reflection.GeneratedProtocolMessageType('ActorTypeList', (_message.Message,), {
  'DESCRIPTOR' : _ACTORTYPELIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorTypeList)
  })
_sym_db.RegisterMessage(ActorTypeList)

VehicleCtrlCmd = _reflection.GeneratedProtocolMessageType('VehicleCtrlCmd', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLECTRLCMD,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleCtrlCmd)
  })
_sym_db.RegisterMessage(VehicleCtrlCmd)

WalkerCtrlCmd = _reflection.GeneratedProtocolMessageType('WalkerCtrlCmd', (_message.Message,), {
  'DESCRIPTOR' : _WALKERCTRLCMD,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.WalkerCtrlCmd)
  })
_sym_db.RegisterMessage(WalkerCtrlCmd)

ActorStates = _reflection.GeneratedProtocolMessageType('ActorStates', (_message.Message,), {
  'DESCRIPTOR' : _ACTORSTATES,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorStates)
  })
_sym_db.RegisterMessage(ActorStates)

ActorState = _reflection.GeneratedProtocolMessageType('ActorState', (_message.Message,), {
  'DESCRIPTOR' : _ACTORSTATE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorState)
  })
_sym_db.RegisterMessage(ActorState)

VehicleState = _reflection.GeneratedProtocolMessageType('VehicleState', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESTATE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleState)
  })
_sym_db.RegisterMessage(VehicleState)

VehicleAuxState = _reflection.GeneratedProtocolMessageType('VehicleAuxState', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEAUXSTATE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleAuxState)
  })
_sym_db.RegisterMessage(VehicleAuxState)

VehicleSpawnParam = _reflection.GeneratedProtocolMessageType('VehicleSpawnParam', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESPAWNPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleSpawnParam)
  })
_sym_db.RegisterMessage(VehicleSpawnParam)

PedestrianSpawnParam = _reflection.GeneratedProtocolMessageType('PedestrianSpawnParam', (_message.Message,), {
  'DESCRIPTOR' : _PEDESTRIANSPAWNPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.PedestrianSpawnParam)
  })
_sym_db.RegisterMessage(PedestrianSpawnParam)

ObstacleSpawnParam = _reflection.GeneratedProtocolMessageType('ObstacleSpawnParam', (_message.Message,), {
  'DESCRIPTOR' : _OBSTACLESPAWNPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ObstacleSpawnParam)
  })
_sym_db.RegisterMessage(ObstacleSpawnParam)

ActorResponse = _reflection.GeneratedProtocolMessageType('ActorResponse', (_message.Message,), {
  'DESCRIPTOR' : _ACTORRESPONSE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorResponse)
  })
_sym_db.RegisterMessage(ActorResponse)

ActorResponses = _reflection.GeneratedProtocolMessageType('ActorResponses', (_message.Message,), {
  'DESCRIPTOR' : _ACTORRESPONSES,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorResponses)
  })
_sym_db.RegisterMessage(ActorResponses)

ActorProperty = _reflection.GeneratedProtocolMessageType('ActorProperty', (_message.Message,), {
  'DESCRIPTOR' : _ACTORPROPERTY,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ActorProperty)
  })
_sym_db.RegisterMessage(ActorProperty)

NetworkConfig = _reflection.GeneratedProtocolMessageType('NetworkConfig', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKCONFIG,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.NetworkConfig)
  })
_sym_db.RegisterMessage(NetworkConfig)

NetworkIpSetting = _reflection.GeneratedProtocolMessageType('NetworkIpSetting', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKIPSETTING,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.NetworkIpSetting)
  })
_sym_db.RegisterMessage(NetworkIpSetting)

NetworkProtocolSetting = _reflection.GeneratedProtocolMessageType('NetworkProtocolSetting', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKPROTOCOLSETTING,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.NetworkProtocolSetting)
  })
_sym_db.RegisterMessage(NetworkProtocolSetting)

NetworkProtocolItem = _reflection.GeneratedProtocolMessageType('NetworkProtocolItem', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKPROTOCOLITEM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.NetworkProtocolItem)
  })
_sym_db.RegisterMessage(NetworkProtocolItem)

NetworkItem = _reflection.GeneratedProtocolMessageType('NetworkItem', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKITEM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.NetworkItem)
  })
_sym_db.RegisterMessage(NetworkItem)

TrafficLight = _reflection.GeneratedProtocolMessageType('TrafficLight', (_message.Message,), {

  'TLSchedule' : _reflection.GeneratedProtocolMessageType('TLSchedule', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICLIGHT_TLSCHEDULE,
    '__module__' : 'morai_actor_pb2'
    # @@protoc_insertion_point(class_scope:morai_sim_api.TrafficLight.TLSchedule)
    })
  ,

  'PSSchedule' : _reflection.GeneratedProtocolMessageType('PSSchedule', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICLIGHT_PSSCHEDULE,
    '__module__' : 'morai_actor_pb2'
    # @@protoc_insertion_point(class_scope:morai_sim_api.TrafficLight.PSSchedule)
    })
  ,

  'YellowSchedule' : _reflection.GeneratedProtocolMessageType('YellowSchedule', (_message.Message,), {
    'DESCRIPTOR' : _TRAFFICLIGHT_YELLOWSCHEDULE,
    '__module__' : 'morai_actor_pb2'
    # @@protoc_insertion_point(class_scope:morai_sim_api.TrafficLight.YellowSchedule)
    })
  ,
  'DESCRIPTOR' : _TRAFFICLIGHT,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.TrafficLight)
  })
_sym_db.RegisterMessage(TrafficLight)
_sym_db.RegisterMessage(TrafficLight.TLSchedule)
_sym_db.RegisterMessage(TrafficLight.PSSchedule)
_sym_db.RegisterMessage(TrafficLight.YellowSchedule)

TLInfo = _reflection.GeneratedProtocolMessageType('TLInfo', (_message.Message,), {
  'DESCRIPTOR' : _TLINFO,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.TLInfo)
  })
_sym_db.RegisterMessage(TLInfo)

TLInfoList = _reflection.GeneratedProtocolMessageType('TLInfoList', (_message.Message,), {
  'DESCRIPTOR' : _TLINFOLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.TLInfoList)
  })
_sym_db.RegisterMessage(TLInfoList)

TLStateParam = _reflection.GeneratedProtocolMessageType('TLStateParam', (_message.Message,), {
  'DESCRIPTOR' : _TLSTATEPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.TLStateParam)
  })
_sym_db.RegisterMessage(TLStateParam)

TLStateParamList = _reflection.GeneratedProtocolMessageType('TLStateParamList', (_message.Message,), {
  'DESCRIPTOR' : _TLSTATEPARAMLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.TLStateParamList)
  })
_sym_db.RegisterMessage(TLStateParamList)

IntscnStateParam = _reflection.GeneratedProtocolMessageType('IntscnStateParam', (_message.Message,), {
  'DESCRIPTOR' : _INTSCNSTATEPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.IntscnStateParam)
  })
_sym_db.RegisterMessage(IntscnStateParam)

IntscnStateParamList = _reflection.GeneratedProtocolMessageType('IntscnStateParamList', (_message.Message,), {
  'DESCRIPTOR' : _INTSCNSTATEPARAMLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.IntscnStateParamList)
  })
_sym_db.RegisterMessage(IntscnStateParamList)

IntersectionScheduleData = _reflection.GeneratedProtocolMessageType('IntersectionScheduleData', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTIONSCHEDULEDATA,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.IntersectionScheduleData)
  })
_sym_db.RegisterMessage(IntersectionScheduleData)

IntscnScheduleParamList = _reflection.GeneratedProtocolMessageType('IntscnScheduleParamList', (_message.Message,), {
  'DESCRIPTOR' : _INTSCNSCHEDULEPARAMLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.IntscnScheduleParamList)
  })
_sym_db.RegisterMessage(IntscnScheduleParamList)

VehicleRoute = _reflection.GeneratedProtocolMessageType('VehicleRoute', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEROUTE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleRoute)
  })
_sym_db.RegisterMessage(VehicleRoute)

VehicleDestination = _reflection.GeneratedProtocolMessageType('VehicleDestination', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDESTINATION,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleDestination)
  })
_sym_db.RegisterMessage(VehicleDestination)

EgoCtrlCmd = _reflection.GeneratedProtocolMessageType('EgoCtrlCmd', (_message.Message,), {
  'DESCRIPTOR' : _EGOCTRLCMD,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.EgoCtrlCmd)
  })
_sym_db.RegisterMessage(EgoCtrlCmd)

EgoCruiseCtrl = _reflection.GeneratedProtocolMessageType('EgoCruiseCtrl', (_message.Message,), {
  'DESCRIPTOR' : _EGOCRUISECTRL,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.EgoCruiseCtrl)
  })
_sym_db.RegisterMessage(EgoCruiseCtrl)

VehicleEventControl = _reflection.GeneratedProtocolMessageType('VehicleEventControl', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEEVENTCONTROL,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleEventControl)
  })
_sym_db.RegisterMessage(VehicleEventControl)

Disturbance = _reflection.GeneratedProtocolMessageType('Disturbance', (_message.Message,), {
  'DESCRIPTOR' : _DISTURBANCE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.Disturbance)
  })
_sym_db.RegisterMessage(Disturbance)

DisturbanceVehicle = _reflection.GeneratedProtocolMessageType('DisturbanceVehicle', (_message.Message,), {
  'DESCRIPTOR' : _DISTURBANCEVEHICLE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.DisturbanceVehicle)
  })
_sym_db.RegisterMessage(DisturbanceVehicle)

DisturbanceVehicleList = _reflection.GeneratedProtocolMessageType('DisturbanceVehicleList', (_message.Message,), {
  'DESCRIPTOR' : _DISTURBANCEVEHICLELIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.DisturbanceVehicleList)
  })
_sym_db.RegisterMessage(DisturbanceVehicleList)

ScenarioETC = _reflection.GeneratedProtocolMessageType('ScenarioETC', (_message.Message,), {
  'DESCRIPTOR' : _SCENARIOETC,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.ScenarioETC)
  })
_sym_db.RegisterMessage(ScenarioETC)

VehicleClass = _reflection.GeneratedProtocolMessageType('VehicleClass', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLECLASS,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleClass)
  })
_sym_db.RegisterMessage(VehicleClass)

BiasMode = _reflection.GeneratedProtocolMessageType('BiasMode', (_message.Message,), {
  'DESCRIPTOR' : _BIASMODE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.BiasMode)
  })
_sym_db.RegisterMessage(BiasMode)

CreateSpawnPoint = _reflection.GeneratedProtocolMessageType('CreateSpawnPoint', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPAWNPOINT,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.CreateSpawnPoint)
  })
_sym_db.RegisterMessage(CreateSpawnPoint)

CreateSpawnPointList = _reflection.GeneratedProtocolMessageType('CreateSpawnPointList', (_message.Message,), {
  'DESCRIPTOR' : _CREATESPAWNPOINTLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.CreateSpawnPointList)
  })
_sym_db.RegisterMessage(CreateSpawnPointList)

EnableSpawnPoint = _reflection.GeneratedProtocolMessageType('EnableSpawnPoint', (_message.Message,), {
  'DESCRIPTOR' : _ENABLESPAWNPOINT,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.EnableSpawnPoint)
  })
_sym_db.RegisterMessage(EnableSpawnPoint)

EnableSpawnPointList = _reflection.GeneratedProtocolMessageType('EnableSpawnPointList', (_message.Message,), {
  'DESCRIPTOR' : _ENABLESPAWNPOINTLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.EnableSpawnPointList)
  })
_sym_db.RegisterMessage(EnableSpawnPointList)

SpawnPointInfo = _reflection.GeneratedProtocolMessageType('SpawnPointInfo', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNPOINTINFO,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SpawnPointInfo)
  })
_sym_db.RegisterMessage(SpawnPointInfo)

SetSpawnPoint = _reflection.GeneratedProtocolMessageType('SetSpawnPoint', (_message.Message,), {
  'DESCRIPTOR' : _SETSPAWNPOINT,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SetSpawnPoint)
  })
_sym_db.RegisterMessage(SetSpawnPoint)

SetSpawnPointList = _reflection.GeneratedProtocolMessageType('SetSpawnPointList', (_message.Message,), {
  'DESCRIPTOR' : _SETSPAWNPOINTLIST,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SetSpawnPointList)
  })
_sym_db.RegisterMessage(SetSpawnPointList)

VehicleLimiter = _reflection.GeneratedProtocolMessageType('VehicleLimiter', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLELIMITER,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleLimiter)
  })
_sym_db.RegisterMessage(VehicleLimiter)

VehicleControlState = _reflection.GeneratedProtocolMessageType('VehicleControlState', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLECONTROLSTATE,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleControlState)
  })
_sym_db.RegisterMessage(VehicleControlState)

VehicleDynamics = _reflection.GeneratedProtocolMessageType('VehicleDynamics', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDYNAMICS,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleDynamics)
  })
_sym_db.RegisterMessage(VehicleDynamics)

VehicleDynamicsSteer = _reflection.GeneratedProtocolMessageType('VehicleDynamicsSteer', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDYNAMICSSTEER,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleDynamicsSteer)
  })
_sym_db.RegisterMessage(VehicleDynamicsSteer)

VehicleDynamicsSpeedLimit = _reflection.GeneratedProtocolMessageType('VehicleDynamicsSpeedLimit', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDYNAMICSSPEEDLIMIT,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleDynamicsSpeedLimit)
  })
_sym_db.RegisterMessage(VehicleDynamicsSpeedLimit)

VehicleDynamicsMass = _reflection.GeneratedProtocolMessageType('VehicleDynamicsMass', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEDYNAMICSMASS,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleDynamicsMass)
  })
_sym_db.RegisterMessage(VehicleDynamicsMass)

VehicleSpecParam = _reflection.GeneratedProtocolMessageType('VehicleSpecParam', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESPECPARAM,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleSpecParam)
  })
_sym_db.RegisterMessage(VehicleSpecParam)

VehicleSpecData = _reflection.GeneratedProtocolMessageType('VehicleSpecData', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESPECDATA,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleSpecData)
  })
_sym_db.RegisterMessage(VehicleSpecData)

DynamicsLevel = _reflection.GeneratedProtocolMessageType('DynamicsLevel', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICSLEVEL,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.DynamicsLevel)
  })
_sym_db.RegisterMessage(DynamicsLevel)

VehicleSpec = _reflection.GeneratedProtocolMessageType('VehicleSpec', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESPEC,
  '__module__' : 'morai_actor_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.VehicleSpec)
  })
_sym_db.RegisterMessage(VehicleSpec)

_MORAIACTOR = DESCRIPTOR.services_by_name['MoraiActor']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\252\002!CoreLib.Grpc.Protobuf.MoraiSimAPI'
  _ACTORTYPE._serialized_start=8568
  _ACTORTYPE._serialized_end=8679
  _VEHICLETYPE._serialized_start=8681
  _VEHICLETYPE._serialized_end=8800
  _VEHICLEDRIVINGPARAMTYPE._serialized_start=8803
  _VEHICLEDRIVINGPARAMTYPE._serialized_end=8984
  _VEHICLEVELOCITYTYPE._serialized_start=8987
  _VEHICLEVELOCITYTYPE._serialized_end=9122
  _ACTORPROPERTYTYPE._serialized_start=9125
  _ACTORPROPERTYTYPE._serialized_end=9438
  _VEHICLEDYNAMICSTYPE._serialized_start=9440
  _VEHICLEDYNAMICSTYPE._serialized_end=9550
  _GEARMODE._serialized_start=9552
  _GEARMODE._serialized_end=9664
  _CRUISE_TYPE._serialized_start=9666
  _CRUISE_TYPE._serialized_end=9771
  _TRAFFICLIGHTCOLOR._serialized_start=9774
  _TRAFFICLIGHTCOLOR._serialized_end=10253
  _NETWORKCOMMTYPE._serialized_start=10256
  _NETWORKCOMMTYPE._serialized_end=10529
  _NETWORKITEMTYPE._serialized_start=10532
  _NETWORKITEMTYPE._serialized_end=11332
  _PUBSUB_TYPE._serialized_start=11335
  _PUBSUB_TYPE._serialized_end=16522
  _NETWORKCONNETTYPE._serialized_start=16525
  _NETWORKCONNETTYPE._serialized_end=16699
  _SPAWNACTORPARAMS._serialized_start=83
  _SPAWNACTORPARAMS._serialized_end=149
  _SPAWNACTORPARAM._serialized_start=152
  _SPAWNACTORPARAM._serialized_end=438
  _ACTORINFO._serialized_start=440
  _ACTORINFO._serialized_end=515
  _ACTORINFOS._serialized_start=517
  _ACTORINFOS._serialized_end=571
  _ACTORTYPELIST._serialized_start=573
  _ACTORTYPELIST._serialized_end=608
  _VEHICLECTRLCMD._serialized_start=611
  _VEHICLECTRLCMD._serialized_end=756
  _WALKERCTRLCMD._serialized_start=758
  _WALKERCTRLCMD._serialized_end=849
  _ACTORSTATES._serialized_start=851
  _ACTORSTATES._serialized_end=907
  _ACTORSTATE._serialized_start=910
  _ACTORSTATE._serialized_end=1253
  _VEHICLESTATE._serialized_start=1256
  _VEHICLESTATE._serialized_end=1440
  _VEHICLEAUXSTATE._serialized_start=1443
  _VEHICLEAUXSTATE._serialized_end=1654
  _VEHICLESPAWNPARAM._serialized_start=1656
  _VEHICLESPAWNPARAM._serialized_end=1755
  _PEDESTRIANSPAWNPARAM._serialized_start=1757
  _PEDESTRIANSPAWNPARAM._serialized_end=1884
  _OBSTACLESPAWNPARAM._serialized_start=1886
  _OBSTACLESPAWNPARAM._serialized_end=1968
  _ACTORRESPONSE._serialized_start=1970
  _ACTORRESPONSE._serialized_end=2043
  _ACTORRESPONSES._serialized_start=2045
  _ACTORRESPONSES._serialized_end=2107
  _ACTORPROPERTY._serialized_start=2110
  _ACTORPROPERTY._serialized_end=2616
  _NETWORKCONFIG._serialized_start=2619
  _NETWORKCONFIG._serialized_end=2888
  _NETWORKIPSETTING._serialized_start=2890
  _NETWORKIPSETTING._serialized_end=3007
  _NETWORKPROTOCOLSETTING._serialized_start=3009
  _NETWORKPROTOCOLSETTING._serialized_end=3135
  _NETWORKPROTOCOLITEM._serialized_start=3137
  _NETWORKPROTOCOLITEM._serialized_end=3247
  _NETWORKITEM._serialized_start=3249
  _NETWORKITEM._serialized_end=3323
  _TRAFFICLIGHT._serialized_start=3326
  _TRAFFICLIGHT._serialized_end=3570
  _TRAFFICLIGHT_TLSCHEDULE._serialized_start=3342
  _TRAFFICLIGHT_TLSCHEDULE._serialized_end=3402
  _TRAFFICLIGHT_PSSCHEDULE._serialized_start=3405
  _TRAFFICLIGHT_PSSCHEDULE._serialized_end=3534
  _TRAFFICLIGHT_YELLOWSCHEDULE._serialized_start=3536
  _TRAFFICLIGHT_YELLOWSCHEDULE._serialized_end=3570
  _TLINFO._serialized_start=3572
  _TLINFO._serialized_end=3664
  _TLINFOLIST._serialized_start=3666
  _TLINFOLIST._serialized_end=3719
  _TLSTATEPARAM._serialized_start=3721
  _TLSTATEPARAM._serialized_end=3822
  _TLSTATEPARAMLIST._serialized_start=3824
  _TLSTATEPARAMLIST._serialized_end=3889
  _INTSCNSTATEPARAM._serialized_start=3891
  _INTSCNSTATEPARAM._serialized_end=3947
  _INTSCNSTATEPARAMLIST._serialized_start=3949
  _INTSCNSTATEPARAMLIST._serialized_end=4022
  _INTERSECTIONSCHEDULEDATA._serialized_start=4025
  _INTERSECTIONSCHEDULEDATA._serialized_end=4261
  _INTSCNSCHEDULEPARAMLIST._serialized_start=4263
  _INTSCNSCHEDULEPARAMLIST._serialized_end=4347
  _VEHICLEROUTE._serialized_start=4350
  _VEHICLEROUTE._serialized_end=4524
  _VEHICLEDESTINATION._serialized_start=4527
  _VEHICLEDESTINATION._serialized_end=4709
  _EGOCTRLCMD._serialized_start=4712
  _EGOCTRLCMD._serialized_end=4857
  _EGOCRUISECTRL._serialized_start=4860
  _EGOCRUISECTRL._serialized_end=4996
  _VEHICLEEVENTCONTROL._serialized_start=4999
  _VEHICLEEVENTCONTROL._serialized_end=5160
  _DISTURBANCE._serialized_start=5162
  _DISTURBANCE._serialized_end=5265
  _DISTURBANCE_LOCATION._serialized_start=5177
  _DISTURBANCE_LOCATION._serialized_end=5236
  _DISTURBANCE_TYPE._serialized_start=5238
  _DISTURBANCE_TYPE._serialized_end=5265
  _DISTURBANCEVEHICLE._serialized_start=5268
  _DISTURBANCEVEHICLE._serialized_end=5451
  _DISTURBANCEVEHICLELIST._serialized_start=5453
  _DISTURBANCEVEHICLELIST._serialized_end=5530
  _SCENARIOETC._serialized_start=5532
  _SCENARIOETC._serialized_end=5620
  _SCENARIOETC_SUBCATEGORY._serialized_start=5547
  _SCENARIOETC_SUBCATEGORY._serialized_end=5620
  _VEHICLECLASS._serialized_start=5623
  _VEHICLECLASS._serialized_end=5841
  _VEHICLECLASS_VEHICLELENGTHTYPE._serialized_start=5639
  _VEHICLECLASS_VEHICLELENGTHTYPE._serialized_end=5709
  _VEHICLECLASS_SUBCATEGORY._serialized_start=5712
  _VEHICLECLASS_SUBCATEGORY._serialized_end=5841
  _BIASMODE._serialized_start=5843
  _BIASMODE._serialized_end=5920
  _BIASMODE_LATBIASMODE._serialized_start=5855
  _BIASMODE_LATBIASMODE._serialized_end=5920
  _CREATESPAWNPOINT._serialized_start=5923
  _CREATESPAWNPOINT._serialized_end=6064
  _CREATESPAWNPOINTLIST._serialized_start=6066
  _CREATESPAWNPOINTLIST._serialized_end=6139
  _ENABLESPAWNPOINT._serialized_start=6141
  _ENABLESPAWNPOINT._serialized_end=6197
  _ENABLESPAWNPOINTLIST._serialized_start=6199
  _ENABLESPAWNPOINTLIST._serialized_end=6272
  _SPAWNPOINTINFO._serialized_start=6275
  _SPAWNPOINTINFO._serialized_end=7227
  _SETSPAWNPOINT._serialized_start=7229
  _SETSPAWNPOINT._serialized_end=7350
  _SETSPAWNPOINTLIST._serialized_start=7352
  _SETSPAWNPOINTLIST._serialized_end=7419
  _VEHICLELIMITER._serialized_start=7422
  _VEHICLELIMITER._serialized_end=7566
  _VEHICLECONTROLSTATE._serialized_start=7568
  _VEHICLECONTROLSTATE._serialized_end=7622
  _VEHICLEDYNAMICS._serialized_start=7625
  _VEHICLEDYNAMICS._serialized_end=7899
  _VEHICLEDYNAMICSSTEER._serialized_start=7901
  _VEHICLEDYNAMICSSTEER._serialized_end=7948
  _VEHICLEDYNAMICSSPEEDLIMIT._serialized_start=7950
  _VEHICLEDYNAMICSSPEEDLIMIT._serialized_end=8021
  _VEHICLEDYNAMICSMASS._serialized_start=8023
  _VEHICLEDYNAMICSMASS._serialized_end=8058
  _VEHICLESPECPARAM._serialized_start=8060
  _VEHICLESPECPARAM._serialized_end=8138
  _VEHICLESPECDATA._serialized_start=8141
  _VEHICLESPECDATA._serialized_end=8417
  _DYNAMICSLEVEL._serialized_start=8419
  _DYNAMICSLEVEL._serialized_end=8475
  _VEHICLESPEC._serialized_start=8477
  _VEHICLESPEC._serialized_end=8566
  _MORAIACTOR._serialized_start=16702
  _MORAIACTOR._serialized_end=18570
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import morai_sensor_pb2 as morai__sensor__pb2
import morai_type_pb2 as morai__type__pb2


class MoraiSensorStub(object):
    """*
    Sensor 관련 서비스
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AddSensor = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/AddSensor',
                request_serializer=morai__sensor__pb2.SensorSettingList.SerializeToString,
                response_deserializer=morai__sensor__pb2.SensorResponseList.FromString,
                )
        self.RemoveSensor = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/RemoveSensor',
                request_serializer=morai__sensor__pb2.RemoveSensorList.SerializeToString,
                response_deserializer=morai__sensor__pb2.SensorResponseList.FromString,
                )
        self.SetGroundTruthSensor = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/SetGroundTruthSensor',
                request_serializer=morai__sensor__pb2.SetGroundTruthSensorList.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.GetGroundTruthData = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/GetGroundTruthData',
                request_serializer=morai__sensor__pb2.TargetSensorList.SerializeToString,
                response_deserializer=morai__sensor__pb2.GroundTruthList.FromString,
                )
        self.SaveSensorData = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/SaveSensorData',
                request_serializer=morai__sensor__pb2.SaveSensor.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )
        self.LoadSensorFile = channel.unary_unary(
                '/morai_sim_api.MoraiSensor/LoadSensorFile',
                request_serializer=morai__type__pb2.StringValue.SerializeToString,
                response_deserializer=morai__type__pb2.Result.FromString,
                )


class MoraiSensorServicer(object):
    """*
    Sensor 관련 서비스
    """

    def AddSensor(self, request, context):
        """차량에 센서 장착
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveSensor(self, request, context):
        """차량에 부착한 센서 제거
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetGroundTruthSensor(self, request, context):
        """GT 센서 설정
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetGroundTruthData(self, request, context):
        """GT 데이터 가져오기
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SaveSensorData(self, request, context):
        """센서 데이터 저장 요청
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSensorFile(self, request, context):
        """센서 설정 파일 로드
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MoraiSensorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AddSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.AddSensor,
                    request_deserializer=morai__sensor__pb2.SensorSettingList.FromString,
                    response_serializer=morai__sensor__pb2.SensorResponseList.SerializeToString,
            ),
            'RemoveSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveSensor,
                    request_deserializer=morai__sensor__pb2.RemoveSensorList.FromString,
                    response_serializer=morai__sensor__pb2.SensorResponseList.SerializeToString,
            ),
            'SetGroundTruthSensor': grpc.unary_unary_rpc_method_handler(
                    servicer.SetGroundTruthSensor,
                    request_deserializer=morai__sensor__pb2.SetGroundTruthSensorList.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'GetGroundTruthData': grpc.unary_unary_rpc_method_handler(
                    servicer.GetGroundTruthData,
                    request_deserializer=morai__sensor__pb2.TargetSensorList.FromString,
                    response_serializer=morai__sensor__pb2.GroundTruthList.SerializeToString,
            ),
            'SaveSensorData': grpc.unary_unary_rpc_method_handler(
                    servicer.SaveSensorData,
                    request_deserializer=morai__sensor__pb2.SaveSensor.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
            'LoadSensorFile': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadSensorFile,
                    request_deserializer=morai__type__pb2.StringValue.FromString,
                    response_serializer=morai__type__pb2.Result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'morai_sim_api.MoraiSensor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class MoraiSensor(object):
    """*
    Sensor 관련 서비스
    """

    @staticmethod
    def AddSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/AddSensor',
            morai__sensor__pb2.SensorSettingList.SerializeToString,
            morai__sensor__pb2.SensorResponseList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/RemoveSensor',
            morai__sensor__pb2.RemoveSensorList.SerializeToString,
            morai__sensor__pb2.SensorResponseList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetGroundTruthSensor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/SetGroundTruthSensor',
            morai__sensor__pb2.SetGroundTruthSensorList.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetGroundTruthData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/GetGroundTruthData',
            morai__sensor__pb2.TargetSensorList.SerializeToString,
            morai__sensor__pb2.GroundTruthList.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SaveSensorData(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/SaveSensorData',
            morai__sensor__pb2.SaveSensor.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadSensorFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/morai_sim_api.MoraiSensor/LoadSensorFile',
            morai__type__pb2.StringValue.SerializeToString,
            morai__type__pb2.Result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: morai_simulation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import morai_type_pb2 as morai__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16morai_simulation.proto\x12\rmorai_sim_api\x1a\x1bgoogle/protobuf/empty.proto\x1a\x10morai_type.proto\"@\n\x0cWeatherParam\x12\x30\n\x0cweather_type\x18\x01 \x01(\x0e\x32\x1a.morai_sim_api.WeatherType\"K\n\x0eLoadWorldParam\x12\x10\n\x08map_name\x18\x01 \x01(\t\x12\x19\n\x11\x65go_vehicle_model\x18\x02 \x01(\t\x12\x0c\n\x04wait\x18\x03 \x01(\x08\"\x0e\n\x0cSensorConfig\"p\n\x0cRaycastParam\x12&\n\x06source\x18\x01 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12&\n\x06target\x18\x02 \x01(\x0b\x32\x16.morai_sim_api.Vector3\x12\x10\n\x08max_dist\x18\x03 \x01(\x02*\x9e\x01\n\x0bWeatherType\x12\x16\n\x12WEATHER_TYPE_SUNNY\x10\x00\x12\x17\n\x13WEATHER_TYPE_CLOUDY\x10\x01\x12\x16\n\x12WEATHER_TYPE_FOGGY\x10\x02\x12\x16\n\x12WEATHER_TYPE_STORM\x10\x03\x12\x16\n\x12WEATHER_TYPE_RAINY\x10\x04\x12\x16\n\x12WEATHER_TYPE_SNOWY\x10\x05\x32\xac\t\n\x0fMoraiSimulation\x12>\n\nInitialize\x12\x16.google.protobuf.Empty\x1a\x16.google.protobuf.Empty\"\x00\x12G\n\x11IsSynchronousMode\x12\x16.google.protobuf.Empty\x1a\x18.morai_sim_api.BoolValue\"\x00\x12G\n\x12SetSynchronousMode\x12\x18.morai_sim_api.BoolValue\x1a\x15.morai_sim_api.Result\"\x00\x12?\n\x04Tick\x12\x19.morai_sim_api.Int32Value\x1a\x1a.morai_sim_api.Uint64Value\"\x00\x12\x42\n\x0bWaitForTick\x12\x16.google.protobuf.Empty\x1a\x19.morai_sim_api.Int64Value\"\x00\x12\x45\n\rGetEnviroTime\x12\x16.google.protobuf.Empty\x1a\x1a.morai_sim_api.Uint32Value\"\x00\x12\x44\n\rSetEnviroTime\x12\x1a.morai_sim_api.Uint32Value\x1a\x15.morai_sim_api.Result\"\x00\x12\x38\n\x05Pause\x12\x16.google.protobuf.Empty\x1a\x15.morai_sim_api.Result\"\x00\x12\x39\n\x06Resume\x12\x16.google.protobuf.Empty\x1a\x15.morai_sim_api.Result\"\x00\x12\x42\n\nSetWeather\x12\x1b.morai_sim_api.WeatherParam\x1a\x15.morai_sim_api.Result\"\x00\x12\x43\n\nGetWeather\x12\x16.google.protobuf.Empty\x1a\x1b.morai_sim_api.WeatherParam\"\x00\x12\x43\n\tLoadWorld\x12\x1d.morai_sim_api.LoadWorldParam\x1a\x15.morai_sim_api.Result\"\x00\x12J\n\x13LoadBuiltInScenario\x12\x1a.morai_sim_api.StringValue\x1a\x15.morai_sim_api.Result\"\x00\x12H\n\x10LoadSensorConfig\x12\x1b.morai_sim_api.SensorConfig\x1a\x15.morai_sim_api.Result\"\x00\x12I\n\x11GetCurrentMapName\x12\x16.google.protobuf.Empty\x1a\x1a.morai_sim_api.StringValue\"\x00\x12L\n\x15SetSimulatorTimeScale\x12\x19.morai_sim_api.FloatValue\x1a\x16.google.protobuf.Empty\"\x00\x12\x43\n\x07RayCast\x12\x1b.morai_sim_api.RaycastParam\x1a\x19.morai_sim_api.FloatValue\"\x00\x42&H\x01\xaa\x02!CoreLib.Grpc.Protobuf.MoraiSimAPIb\x06proto3')

_WEATHERTYPE = DESCRIPTOR.enum_types_by_name['WeatherType']
WeatherType = enum_type_wrapper.EnumTypeWrapper(_WEATHERTYPE)
WEATHER_TYPE_SUNNY = 0
WEATHER_TYPE_CLOUDY = 1
WEATHER_TYPE_FOGGY = 2
WEATHER_TYPE_STORM = 3
WEATHER_TYPE_RAINY = 4
WEATHER_TYPE_SNOWY = 5


_WEATHERPARAM = DESCRIPTOR.message_types_by_name['WeatherParam']
_LOADWORLDPARAM = DESCRIPTOR.message_types_by_name['LoadWorldParam']
_SENSORCONFIG = DESCRIPTOR.message_types_by_name['SensorConfig']
_RAYCASTPARAM = DESCRIPTOR.message_types_by_name['RaycastParam']
WeatherParam = _reflection.GeneratedProtocolMessageType('WeatherParam', (_message.Message,), {
  'DESCRIPTOR' : _WEATHERPARAM,
  '__module__' : 'morai_simulation_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.WeatherParam)
  })
_sym_db.RegisterMessage(WeatherParam)

LoadWorldParam = _reflection.GeneratedProtocolMessageType('LoadWorldParam', (_message.Message,), {
  'DESCRIPTOR' : _LOADWORLDPARAM,
  '__module__' : 'morai_simulation_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.LoadWorldParam)
  })
_sym_db.RegisterMessage(LoadWorldParam)

SensorConfig = _reflection.GeneratedProtocolMessageType('SensorConfig', (_message.Message,), {
  'DESCRIPTOR' : _SENSORCONFIG,
  '__module__' : 'morai_simulation_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.SensorConfig)
  })
_sym_db.RegisterMessage(SensorConfig)

RaycastParam = _reflection.GeneratedProtocolMessageType('RaycastParam', (_message.Message,), {
  'DESCRIPTOR' : _RAYCASTPARAM,
  '__module__' : 'morai_simulation_pb2'
  # @@protoc_insertion_point(class_scope:morai_sim_api.RaycastParam)
  })
_sym_db.RegisterMessage(RaycastParam)

_MORAISIMULATION = DESCRIPTOR.services_by_name['MoraiSimulation']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'H\001\252\002!CoreLib.Grpc.Protobuf.MoraiSimAPI'
  _WEATHERTYPE._serialized_start=362
  _WEATHERTYPE._serialized_end=520
  _WEATHERPARAM._serialized_start=88
  _WEATHERPARAM._serialized_end=152
  _LOADWORLDPARAM._serialized_start=154
  _LOADWORLDPARAM._serialized_end=229
  _SENSORCONFIG._serialized_start=231
  _SENSORCONFIG._serialized_end=245
  _RAYCASTPARAM._serialized_start=247
  _RAYCASTPARAM._serialized_end=359
  _MORAISIMULATION._serialized_start=523
  _MORAISIMULATION._serialized_end=1719
# @@protoc_insertion_point(module_scope)
